@@ -46,11 +46,11 @@
  *                MdcGetHeartRate()     - Get heart rate from gated data   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -1013,7 +1013,7 @@ void MdcPrefix(int n)
   }
 
   if (n < 1000) {
-    sprintf(cprefix,"m%03d-",n);
+    sprintf(cprefix,"m%03u-", (unsigned int) n);
   }else{
      t = n - 1000;
     v1 = t / 1296;
