@@ -41,11 +41,11 @@
  *                We only write GIF89a animated gifs                       *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -760,7 +760,7 @@ char *MdcWriteGIF(FILEINFO *fi)
      }
   }
 
-  if ( MdcWriteApplicationBlock(fi,MDC_PRGR,"NLF"))
+  if ( MdcWriteApplicationBlock(fi,PACKAGE_NAME,"NLF"))
     return("GIF  Bad write application block");
 
   if ( fputc(';',fi->ofp) == EOF ) return("GIF  Bad write terminator code");
