@@ -12,7 +12,7 @@
  *                XMdcColorMapCallbackClicked()  - Clicked colormap        *
  *                XMdcColorMapSelCallbackApply() - Apply   callback        *
  *                XMdcColorMapSel()              - Select map & colors     *
- *                XMdcColorMapCallbackExpose()   - Expose  callback        *
+ *                XMdcColorMapCallbackDraw()     - Draw callback           *
  *                XMdcApplyMapPlace()            - Apply new placement     *
  *                XMdcMapPlaceSel()              - Select map placement    *
  *                XMdcMapPlaceSelCallbackApply() - Apply place selection   *
@@ -23,11 +23,11 @@
  *                                                                         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -120,28 +120,28 @@ gboolean XMdcColorMapCallbackClicked(GtkWidget *widget, GdkEventButton *button,
   return(TRUE);
 }
 
-void XMdcColorMapSelCallbackApply (GtkWidget *widget, gpointer data)
+void XMdcColorMapSelCallbackApply(GtkWidget *widget, gpointer data)
 {
   gint map=MDC_MAP_GRAY;
 
   if (XMdcMapNotAllowed() == TRUE) return;
 
   MdcDebugPrint("colormap type: ");
-  if (GTK_TOGGLE_BUTTON(sColormapSelection.Gray)->active)             {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sColormapSelection.Gray)))             {
     MdcDebugPrint("\tgray normal"); map = MDC_MAP_GRAY;
-  }else if (GTK_TOGGLE_BUTTON(sColormapSelection.Inverted)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sColormapSelection.Inverted)))   {
     MdcDebugPrint("\tgray invers"); map = MDC_MAP_INVERTED;
-  }else if (GTK_TOGGLE_BUTTON(sColormapSelection.Rainbow)->active)    {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sColormapSelection.Rainbow)))    {
     MdcDebugPrint("\trainbow");     map = MDC_MAP_RAINBOW;
-  }else if (GTK_TOGGLE_BUTTON(sColormapSelection.Combined)->active)   {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sColormapSelection.Combined)))   {
     MdcDebugPrint("\tcombined");    map = MDC_MAP_COMBINED;
-  }else if (GTK_TOGGLE_BUTTON(sColormapSelection.Hotmetal)->active)   {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sColormapSelection.Hotmetal)))   {
     MdcDebugPrint("\thotmetal");    map = MDC_MAP_HOTMETAL;
-  }else if (GTK_TOGGLE_BUTTON(sColormapSelection.Loaded)->active)     {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sColormapSelection.Loaded)))     {
     MdcDebugPrint("\tloaded");      map = MDC_MAP_LOADED;
   }
 
-  if (map == MDC_MAP_LOADED) { XMdcLutSelOpen(NULL,NULL); return; }
+  if (map == MDC_MAP_LOADED) { XMdcLutSelOpen(); return; }
 
   if (map != sColormapSelection.CurMap) {
     sColormapSelection.CurMap = map; MDC_COLOR_MAP = map;
@@ -170,108 +170,108 @@ gboolean XMdcColorMapSel(void)
 
     wcolor = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-    gtk_signal_connect(GTK_OBJECT(wcolor),"destroy",
-                       GTK_SIGNAL_FUNC(XMdcMedconQuit),NULL);
-    gtk_signal_connect(GTK_OBJECT(wcolor),"delete_event",
-                       GTK_SIGNAL_FUNC(XMdcHandlerToHide),NULL);
+    g_signal_connect(wcolor,"destroy",
+                       G_CALLBACK(XMdcMedconQuit),NULL);
+    g_signal_connect(wcolor,"delete_event",
+                       G_CALLBACK(XMdcHandlerToHide),NULL);
 
 
     gtk_window_set_title(GTK_WINDOW(wcolor),"Palette Selection");
-    gtk_container_set_border_width (GTK_CONTAINER (wcolor), 0);
+    gtk_container_set_border_width(GTK_CONTAINER(wcolor), 0);
 
-    box1 = gtk_vbox_new (FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (wcolor), box1);
+    box1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+    gtk_container_add(GTK_CONTAINER(wcolor), box1);
     gtk_widget_show(box1);
 
     /* create upper box - colormap */
-    box2 = gtk_vbox_new (FALSE, 5);
-    gtk_box_pack_start (GTK_BOX (box1), box2, TRUE, TRUE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER(box2), 5);
+    box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
+    gtk_box_pack_start(GTK_BOX(box1), box2, TRUE, TRUE, 0);
+    gtk_container_set_border_width(GTK_CONTAINER(box2), 5);
     gtk_widget_show(box2);
 
-    box3 = gtk_hbox_new (FALSE, 5);
+    box3 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
     gtk_box_pack_start(GTK_BOX(box2), box3, TRUE, TRUE, 0);
     gtk_widget_show(box3);
 
     /* create colormap frame */
     frame = gtk_frame_new("Color Map");
-    gtk_box_pack_start(GTK_BOX (box3), frame, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box3), frame, TRUE, TRUE, 0);
     gtk_widget_show(frame);
 
-    box4 = gtk_vbox_new(FALSE, 0);
+    box4 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_add(GTK_CONTAINER(frame), box4);
     gtk_container_set_border_width(GTK_CONTAINER(box4), 5);
     gtk_widget_show(box4);
     /* create radiobuttons */
-    button = gtk_radio_button_new_with_label (NULL, "Gray Normal");
-    gtk_box_pack_start (GTK_BOX (box4), button, TRUE, TRUE, 0);
+    button = gtk_radio_button_new_with_label(NULL, "Gray Normal");
+    gtk_box_pack_start(GTK_BOX(box4), button, TRUE, TRUE, 0);
     if (sColormapSelection.CurMap   == MDC_MAP_GRAY)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-    gtk_widget_show (button);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
     sColormapSelection.Gray = button;
 
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group, "Gray Invers");
-    gtk_box_pack_start (GTK_BOX (box4), button, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box4), button, TRUE, TRUE, 0);
     if (sColormapSelection.CurMap   == MDC_MAP_INVERTED)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-    gtk_widget_show (button);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
     sColormapSelection.Inverted = button;
 
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group, "Rainbow");
-    gtk_box_pack_start (GTK_BOX (box4), button, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box4), button, TRUE, TRUE, 0);
     if (sColormapSelection.CurMap == MDC_MAP_RAINBOW)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-    gtk_widget_show (button);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
     sColormapSelection.Rainbow = button;
 
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group, "Combined");
-    gtk_box_pack_start (GTK_BOX (box4), button, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box4), button, TRUE, TRUE, 0);
     if (sColormapSelection.CurMap == MDC_MAP_COMBINED)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-    gtk_widget_show (button);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
     sColormapSelection.Combined = button;
 
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group, "Hotmetal");
-    gtk_box_pack_start (GTK_BOX (box4), button, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box4), button, TRUE, TRUE, 0);
     if (sColormapSelection.CurMap == MDC_MAP_HOTMETAL)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-    gtk_widget_show (button);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
     sColormapSelection.Hotmetal = button;
 
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group, "LUT loaded ...");
-    gtk_box_pack_start (GTK_BOX (box4), button, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box4), button, TRUE, TRUE, 0);
     if (sColormapSelection.CurMap == MDC_MAP_LOADED)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-    gtk_widget_show (button);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
     sColormapSelection.Loaded = button;
 
     /* create horizontal separator */
-    separator = gtk_hseparator_new ();
-    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
-    gtk_widget_show (separator);
+    separator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
+    gtk_box_pack_start(GTK_BOX(box1), separator, FALSE, FALSE, 0);
+    gtk_widget_show(separator);
 
     /* create bottom button box */
-    box2 = gtk_hbox_new (FALSE, 0);
+    box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start(GTK_BOX(box1), box2, TRUE, TRUE, 2);
     gtk_widget_show(box2);
 
     button = gtk_button_new_with_label("Apply");
     gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 2);
-    gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                       GTK_SIGNAL_FUNC(gtk_widget_hide),GTK_OBJECT(wcolor));
-    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                       GTK_SIGNAL_FUNC(XMdcColorMapSelCallbackApply), NULL);
+    g_signal_connect_swapped(button, "clicked",
+                       G_CALLBACK(gtk_widget_hide), wcolor);
+    g_signal_connect(button, "clicked",
+                       G_CALLBACK(XMdcColorMapSelCallbackApply), NULL);
     gtk_widget_show(button);
 
-    button = gtk_button_new_with_label ("Cancel");
+    button = gtk_button_new_with_label("Cancel");
     gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 2);
-    gtk_signal_connect_object(GTK_OBJECT (button), "clicked",
-        GTK_SIGNAL_FUNC(gtk_widget_hide),GTK_OBJECT(wcolor));
+    g_signal_connect_swapped(button, "clicked",
+        G_CALLBACK(gtk_widget_hide), wcolor);
     gtk_widget_show(button);
 
   }else{
@@ -320,23 +320,29 @@ gboolean XMdcColorMapSel(void)
   return(TRUE);
 }
 
-gboolean XMdcColorMapCallbackExpose(GtkWidget *widget,GdkEventExpose *event,gpointer data)
+gboolean XMdcColorMapCallbackDraw(GtkWidget *widget,GdkEventExpose *event,gpointer data)
 {
-  GdkGC *gc = widget->style->white_gc;
-  gint /*w,*/ h;
+  GdkWindow *window;
+  GdkDrawingContext *draw_context;
+  cairo_region_t *cairo_region;
+  cairo_t *cr;
 
-  gdk_window_set_back_pixmap(widget->window, NULL, FALSE);
+  window = gtk_widget_get_window(widget);
 
-  /*w = my.cmap_w;*/
-  h = my.cmap_h;
+  cairo_region = cairo_region_create();
 
-  gdk_pixbuf_render_to_drawable(my.imcmap,widget->window,gc, 0,0,0,0,25,h,
-                                sRenderSelection.Dither,0,0);
+  draw_context = gdk_window_begin_draw_frame(window, cairo_region);
+  cr = gdk_drawing_context_get_cairo_context(draw_context);
+
+  gdk_cairo_set_source_pixbuf(cr, my.imcmap, 0, 0);
+  cairo_paint(cr);
+
+  gdk_window_end_draw_frame(window, draw_context);
+  cairo_region_destroy(cairo_region);
 
   return(TRUE);
 
 }
-
 void XMdcApplyMapPlace(int place)
 {
 
@@ -344,7 +350,7 @@ void XMdcApplyMapPlace(int place)
 
   if (XMDC_FILE_OPEN == MDC_YES) {
 
-    parent = my.cmapbox->parent;
+    parent = gtk_widget_get_parent(my.cmapbox);
 
     switch (place) {
 
@@ -361,12 +367,12 @@ void XMdcApplyMapPlace(int place)
   }
 }
 
-void XMdcMapPlaceSelCallbackApply (GtkWidget *widget, gpointer data)
+void XMdcMapPlaceSelCallbackApply(GtkWidget *widget, gpointer data)
 {
   MdcDebugPrint("colormap location: ");
-  if (GTK_TOGGLE_BUTTON(sMapPlaceSelection.Left)->active)             {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sMapPlaceSelection.Left)))        {
     MdcDebugPrint("\tleft");  XMDC_CMAP_PLACE = MDC_LEFT;
-  }else if (GTK_TOGGLE_BUTTON(sMapPlaceSelection.Right)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sMapPlaceSelection.Right))) {
     MdcDebugPrint("\tright"); XMDC_CMAP_PLACE = MDC_RIGHT;
   }
 
@@ -389,76 +395,76 @@ gboolean XMdcMapPlaceSel(void)
 
     wplace = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-    gtk_signal_connect(GTK_OBJECT(wplace),"destroy",
-                       GTK_SIGNAL_FUNC(XMdcMedconQuit),NULL);
-    gtk_signal_connect(GTK_OBJECT(wplace),"delete_event",
-                       GTK_SIGNAL_FUNC(XMdcHandlerToHide),NULL);
+    g_signal_connect(wplace, "destroy",
+                       G_CALLBACK(XMdcMedconQuit),NULL);
+    g_signal_connect(wplace,"delete_event",
+                       G_CALLBACK(XMdcHandlerToHide),NULL);
 
 
     gtk_window_set_title(GTK_WINDOW(wplace),"Placement Selection");
-    gtk_container_set_border_width (GTK_CONTAINER (wplace), 0);
+    gtk_container_set_border_width(GTK_CONTAINER(wplace), 0);
 
-    box1 = gtk_vbox_new (FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (wplace), box1);
+    box1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+    gtk_container_add(GTK_CONTAINER(wplace), box1);
     gtk_widget_show(box1);
 
     /* create upper box - placement */
-    box2 = gtk_vbox_new (FALSE, 5);
-    gtk_box_pack_start (GTK_BOX (box1), box2, TRUE, TRUE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER(box2), 5);
+    box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
+    gtk_box_pack_start(GTK_BOX(box1), box2, TRUE, TRUE, 0);
+    gtk_container_set_border_width(GTK_CONTAINER(box2), 5);
     gtk_widget_show(box2);
 
-    box3 = gtk_hbox_new (FALSE, 5);
+    box3 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
     gtk_box_pack_start(GTK_BOX(box2), box3, TRUE, TRUE, 0);
     gtk_widget_show(box3);
 
     /* create placement frame */
     frame = gtk_frame_new("Placement");
-    gtk_box_pack_start(GTK_BOX (box3), frame, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box3), frame, TRUE, TRUE, 0);
     gtk_widget_show(frame);
 
-    box4 = gtk_vbox_new(FALSE, 0);
+    box4 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_add(GTK_CONTAINER(frame), box4);
     gtk_container_set_border_width(GTK_CONTAINER(box4), 5);
     gtk_widget_show(box4);
     /* create radiobuttons */
-    button = gtk_radio_button_new_with_label (NULL, "Left  side");
-    gtk_box_pack_start (GTK_BOX (box4), button, TRUE, TRUE, 0);
+    button = gtk_radio_button_new_with_label(NULL, "Left  side");
+    gtk_box_pack_start(GTK_BOX(box4), button, TRUE, TRUE, 0);
     if (XMDC_CMAP_PLACE == MDC_LEFT)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-    gtk_widget_show (button);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
     sMapPlaceSelection.Left = button;
 
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group, "Right side");
-    gtk_box_pack_start (GTK_BOX (box4), button, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box4), button, TRUE, TRUE, 0);
     if (XMDC_CMAP_PLACE == MDC_RIGHT)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-    gtk_widget_show (button);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
     sMapPlaceSelection.Right = button;
 
     /* create horizontal separator */
-    separator = gtk_hseparator_new ();
-    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
-    gtk_widget_show (separator);
+    separator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
+    gtk_box_pack_start(GTK_BOX(box1), separator, FALSE, FALSE, 0);
+    gtk_widget_show(separator);
 
     /* create bottom button box */
-    box2 = gtk_hbox_new (FALSE, 0);
+    box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start(GTK_BOX(box1), box2, TRUE, TRUE, 2);
     gtk_widget_show(box2);
 
     button = gtk_button_new_with_label("Apply");
     gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 2);
-    gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                       GTK_SIGNAL_FUNC(gtk_widget_hide),GTK_OBJECT(wplace));
-    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                       GTK_SIGNAL_FUNC(XMdcMapPlaceSelCallbackApply), NULL);
+    g_signal_connect_swapped(button, "clicked",
+                       G_CALLBACK(gtk_widget_hide), wplace);
+    g_signal_connect(button, "clicked",
+                       G_CALLBACK(XMdcMapPlaceSelCallbackApply), NULL);
     gtk_widget_show(button);
 
-    button = gtk_button_new_with_label ("Cancel");
+    button = gtk_button_new_with_label("Cancel");
     gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 2);
-    gtk_signal_connect_object(GTK_OBJECT (button), "clicked",
-        GTK_SIGNAL_FUNC(gtk_widget_hide),GTK_OBJECT(wplace));
+    g_signal_connect_swapped(button, "clicked",
+        G_CALLBACK(gtk_widget_hide), wplace);
     gtk_widget_show(button);
 
   }else{
@@ -527,21 +533,21 @@ void XMdcBuildColorMap(void)
     gtk_widget_set_events(my.cmap, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK);
     gtk_container_add(GTK_CONTAINER(my.cmapbox), my.cmap);
 
-    gtk_signal_connect(GTK_OBJECT(my.cmap),"button_press_event",
-                       GTK_SIGNAL_FUNC(XMdcColorMapCallbackClicked), NULL);
+    g_signal_connect(my.cmap, "button_press_event",
+                       G_CALLBACK(XMdcColorMapCallbackClicked), NULL);
 
-    gtk_signal_connect(GTK_OBJECT(my.cmap),"expose_event",
-                       GTK_SIGNAL_FUNC(XMdcColorMapCallbackExpose), NULL);
+    g_signal_connect(my.cmap, "draw",
+                       G_CALLBACK(XMdcColorMapCallbackDraw), NULL);
 
   }
 
-  gtk_drawing_area_size(GTK_DRAWING_AREA(my.cmap), my.cmap_w, my.cmap_h);
+  gtk_widget_set_size_request(my.cmap, my.cmap_w, my.cmap_h);
 
   if (my.fi->type != COLRGB) gtk_widget_show(my.cmap);
 
 }
 
-int XMdcLoadLUT(const gchar *lutname)
+int XMdcLoadLUT(char *lutname)
 {
   if (MdcLoadLUT(lutname) == MDC_YES) {
 
