@@ -16,14 +16,16 @@
  *                XMdcDisplayErr()       - Display an error                *
  *                XMdcDisplayFatalErr()  - Display a  fatal error          *
  *                XMdcLogHandler()       - The Glib log output handler     *
- *                XMdcShowErrorConsole() - Show the error console          *
+ *                XMdcCreateLogConsole() - Build glib log window           *
+ *                XMdcShowLogConsole()   - Display glib log window         *
+ *                XMdcCleanLogConsole()  - Clear logs buffer from window   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -43,12 +45,13 @@
                               H E A D E R S
 ****************************************************************************/
 
-/* gtktext was replaced by gtktextview in gtk-2.0, this enables it in 2.0 */
-#define GTK_ENABLE_BROKEN
+#include "m-depend.h"
 
 #include <stdio.h>
 #include <time.h>
-#include <gtk/gtk.h>
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
 
 #include "xmedcon.h"
 
@@ -65,7 +68,7 @@ static GtkWidget *wlogs = NULL;
 
 void XMdcFatalErrorKill(GtkWidget *button, int *code)
 {
-  gtk_exit(-*code);
+  exit(-*code);
 }
 
 void *XMdcDisplayDialog(int code, char *windowtitle, char *info)
@@ -73,47 +76,45 @@ void *XMdcDisplayDialog(int code, char *windowtitle, char *info)
   GtkWidget *dialog;
   GtkWidget *label;
   GtkWidget *button;
+  GtkWidget *content_area;
 
   /* gdk_beep(); */
 
   dialog =  gtk_dialog_new();
 
-  gtk_container_set_border_width(GTK_CONTAINER(GTK_DIALOG(dialog)->action_area),0);
+  content_area = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 
   if (code != MDC_OK) {
-    gtk_signal_connect(GTK_OBJECT(dialog), "destroy",
-                       GTK_SIGNAL_FUNC(XMdcFatalErrorKill), &code);
+    g_signal_connect(dialog, "destroy",
+                       G_CALLBACK(XMdcFatalErrorKill), &code);
   }else{
-    gtk_signal_connect(GTK_OBJECT(dialog),"destroy",
-                       GTK_SIGNAL_FUNC(gtk_widget_destroy), NULL);
+    g_signal_connect(dialog, "destroy",
+                       G_CALLBACK(gtk_widget_destroy), NULL);
   }
-  /* gtk_widget_set_uposition(dialog,100,100); */
-  gtk_window_position(GTK_WINDOW(dialog), GTK_WIN_POS_MOUSE);
+
   gtk_window_set_title(GTK_WINDOW(dialog), windowtitle);
   gtk_container_set_border_width(GTK_CONTAINER(dialog), 0);
-
+  
   label = gtk_label_new(info);
-  gtk_misc_set_padding(GTK_MISC(label), 30, 5);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
-                     label, TRUE, TRUE, 0);
+  gtk_widget_set_margin_start(label, 20);
+  gtk_widget_set_margin_end(label, 20);
+  gtk_widget_set_margin_top(label, 10);
+  gtk_widget_set_margin_bottom(label, 10);
+  gtk_box_pack_start(GTK_BOX(content_area), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
 
-  button = gtk_button_new_with_label("OK");
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area),
-                     button, TRUE, TRUE, 0);
-
+  button = gtk_dialog_add_button(GTK_DIALOG(dialog), "OK", GTK_RESPONSE_OK);
   if (code != MDC_OK) {
-    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                       GTK_SIGNAL_FUNC(XMdcFatalErrorKill), &code);
+    g_signal_connect(button, "clicked",
+                       G_CALLBACK(XMdcFatalErrorKill), &code);
   }else{
-    gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                              GTK_SIGNAL_FUNC(gtk_widget_destroy),
-                              GTK_OBJECT(dialog));
+    g_signal_connect_swapped(button, "clicked",
+                              G_CALLBACK(gtk_widget_destroy),
+                              dialog);
   }
-
   gtk_widget_show(button);
 
-  gtk_widget_show_now(dialog);
+  XMdcRunDialog(dialog);
 
   XMdcUpdateDrawing();
 
@@ -170,6 +171,7 @@ void XMdcDisplayFatalErr(int code, char *fmt, ...)
 void XMdcLogHandler(const gchar *domain, GLogLevelFlags level,
                     const gchar *message, gpointer user_data)
 {
+  GtkTextBuffer *buffer;
   time_t t;
   char *logmsg, timestr[32];
 
@@ -178,25 +180,25 @@ void XMdcLogHandler(const gchar *domain, GLogLevelFlags level,
 
   switch (level) {
     case G_LOG_LEVEL_DEBUG:
-      logmsg = g_strdup_printf("DEBUG   **: %s\n %s\n", timestr, message);
+      logmsg = g_strdup_printf("DEBUG   **: %s ## %s\n", timestr, message);
       break;
     case G_LOG_LEVEL_MESSAGE:
-      logmsg = g_strdup_printf("MESSAGE **: %s\n %s\n", timestr, message);
+      logmsg = g_strdup_printf("MESSAGE **: %s ## %s\n", timestr, message);
       break;
     case G_LOG_LEVEL_WARNING:
-      logmsg = g_strdup_printf("WARNING **: %s\n %s\n", timestr, message);
+      logmsg = g_strdup_printf("WARNING **: %s ## %s\n", timestr, message);
       break;
     case G_LOG_LEVEL_ERROR:
-      logmsg = g_strdup_printf("ERROR   **: %s\n %s\n", timestr, message);
+      logmsg = g_strdup_printf("ERROR   **: %s ## %s\n", timestr, message);
       break;
     default:
-      logmsg = g_strdup_printf("REMARK  **: %s\n %s\n", timestr, message);
+      logmsg = g_strdup_printf("REMARK  **: %s ## %s\n", timestr, message);
   }
 
   if (logmsg == NULL) return;
 
-  gtk_text_insert(GTK_TEXT(wlogs),NULL,NULL,NULL,logmsg,-1);
-  gtk_text_thaw(GTK_TEXT(wlogs));
+  buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(wlogs));
+  gtk_text_buffer_insert_at_cursor(buffer, logmsg, -1); 
   g_free(logmsg);
 
 }
@@ -204,22 +206,21 @@ void XMdcLogHandler(const gchar *domain, GLogLevelFlags level,
 
 void XMdcCreateLogConsole(void)
 {
-  GtkWidget *box1, *box2;
-  GtkWidget *table;
+  GtkWidget *vbox, *hbox;
+  GtkWidget *scrolled_window;
   GtkWidget *button;
   GtkWidget *separator;
-  GtkWidget *vscrollbar;
   char *str;
 
   if (wconsole != NULL) return;
 
   wconsole = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  gtk_widget_set_usize(wconsole, 506, 100);
+  gtk_widget_set_size_request(wconsole, 650, 350);
 
-  gtk_signal_connect(GTK_OBJECT(wconsole), "destroy",
-                     GTK_SIGNAL_FUNC(gtk_widget_destroy), NULL);
-    gtk_signal_connect(GTK_OBJECT(wconsole), "delete_event",
-                     GTK_SIGNAL_FUNC(XMdcHandlerToHide), NULL);
+  g_signal_connect(wconsole, "destroy",
+                     G_CALLBACK(gtk_widget_destroy), NULL);
+  g_signal_connect(wconsole, "delete_event",
+                     G_CALLBACK(XMdcHandlerToHide), NULL);
 
   str = g_strdup_printf("%s Console Logs",MDC_PRGR);
   if (str != NULL) {
@@ -227,60 +228,47 @@ void XMdcCreateLogConsole(void)
     g_free(str);
   }
 
-  box1 = gtk_vbox_new(FALSE,0);
-  gtk_container_add(GTK_CONTAINER(wconsole), box1);
-  gtk_widget_show(box1);
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL,0);
+  gtk_container_add(GTK_CONTAINER(wconsole),vbox);
+  gtk_widget_show(vbox);
 
-  box2 = gtk_vbox_new(FALSE,0);
-  gtk_container_set_border_width(GTK_CONTAINER(box2),0);
-  gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,0);
-  gtk_widget_show(box2);
+  scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+  gtk_box_pack_start(GTK_BOX(vbox),scrolled_window,TRUE,TRUE,0);
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
+                                 GTK_POLICY_AUTOMATIC,
+                                 GTK_POLICY_AUTOMATIC);
+  gtk_widget_show(scrolled_window);
 
-  table = gtk_table_new(2, 2, FALSE);
-  gtk_table_set_row_spacing(GTK_TABLE(table), 0, 2);
-  gtk_table_set_col_spacing(GTK_TABLE(table), 0, 2);
-  gtk_box_pack_start(GTK_BOX(box2),table,TRUE,TRUE,0);
-  gtk_widget_show(table);
-
-  wlogs = gtk_text_new(NULL,NULL);
-  gtk_text_set_editable(GTK_TEXT(wlogs),FALSE);
-  gtk_text_set_word_wrap(GTK_TEXT(wlogs), TRUE);
-  gtk_table_attach(GTK_TABLE(table),wlogs, 0, 1, 0, 1,
-                   GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                   GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
+  wlogs = gtk_text_view_new();
+  gtk_text_view_set_editable(GTK_TEXT_VIEW(wlogs),FALSE);
+  gtk_widget_set_name(wlogs, "TextView");
+  gtk_container_add(GTK_CONTAINER(scrolled_window),wlogs);
   gtk_widget_show(wlogs);
 
-  vscrollbar = gtk_vscrollbar_new(GTK_TEXT(wlogs)->vadj);
-  gtk_table_attach(GTK_TABLE(table), vscrollbar, 1, 2, 0, 1,
-                   GTK_FILL, GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
-  gtk_widget_show(vscrollbar);
-
-  gtk_widget_show(wlogs);
-
-  separator = gtk_hseparator_new();
-  gtk_box_pack_start(GTK_BOX(box1),separator,FALSE,TRUE,0);
+  separator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
+  gtk_box_pack_start(GTK_BOX(vbox),separator,FALSE,TRUE,0);
   gtk_widget_show(separator);
 
-  box2 = gtk_hbox_new(FALSE,0);
-  gtk_container_set_border_width(GTK_CONTAINER(box2),0);
-  gtk_box_pack_start(GTK_BOX(box1),box2,FALSE,FALSE,0);
-  gtk_widget_show(box2);
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
+  gtk_container_set_border_width(GTK_CONTAINER(hbox),0);
+  gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
+  gtk_widget_show(hbox);
 
 
   button = gtk_button_new_with_label("Clear");
-  gtk_signal_connect(GTK_OBJECT(button),"clicked",
-                     GTK_SIGNAL_FUNC(XMdcClearLogConsole),NULL);
-  gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
+  g_signal_connect(button, "clicked",
+                     G_CALLBACK(XMdcClearLogConsole),NULL);
+  gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,2);
   gtk_widget_show(button);
 
   button = gtk_button_new_with_label("Close");
-  gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
-                            GTK_SIGNAL_FUNC(gtk_widget_hide),
-                            GTK_OBJECT(wconsole));
-  gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
+  g_signal_connect_swapped(button, "clicked",
+                            G_CALLBACK(gtk_widget_hide),
+                            wconsole);
+  gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,2);
   gtk_widget_show(button);
 
-  g_log_set_handler(MDC_PRGR,G_LOG_LEVEL_MASK,XMdcLogHandler, NULL);
+  g_log_set_handler(MDC_PRGR,G_LOG_LEVEL_MASK,XMdcLogHandler,NULL);
 
 }
 
@@ -294,6 +282,8 @@ void XMdcShowLogConsole(void)
 
 void XMdcClearLogConsole(void)
 {
-  gtk_editable_delete_text(
-     GTK_EDITABLE(wlogs), 0, (gint)gtk_text_get_length(GTK_TEXT(wlogs)));
+  GtkTextBuffer *new_buffer = gtk_text_buffer_new(NULL);
+
+  gtk_text_view_set_buffer(GTK_TEXT_VIEW(wlogs),new_buffer);
+
 }
