@@ -17,11 +17,11 @@
  *                XMdcExtractStyleSel()               - Extract Style Sel  *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -64,8 +64,6 @@
 
 static int BUSSY = MDC_NO;
 
-static GtkWidget  *wextract=NULL;
-
 /****************************************************************************
                             F U N C T I O N S
 ****************************************************************************/
@@ -251,14 +249,13 @@ void XMdcGetImagesCallbackApply(GtkWidget *widget, gpointer data)
 }
 
 
-
-void XMdcGetImages(void)
+void XMdcGetImages(GtkWidget *widget, guint style)
 {
    GtkWidget *window=NULL;
    GtkWidget *box1;
    GtkWidget *box2;
    GtkWidget *box3;
-   GtkWidget *table;
+   GtkWidget *grid;
    GtkWidget *frame;
    GtkWidget *label;
    GtkWidget *button;
@@ -266,12 +263,16 @@ void XMdcGetImages(void)
    GtkWidget *planes, *frames, *gates, *beds;
    MdcExtractInputStruct *input = sExtractSelection.input;
 
+   if (XMdcNoFileOpened()) return;
+
+   input->style = (Int32)style;
+
    window = gtk_window_new(GTK_WINDOW_TOPLEVEL); BUSSY = MDC_YES;
 
-   gtk_signal_connect(GTK_OBJECT(window),"destroy",
-                      GTK_SIGNAL_FUNC(XMdcExtractNotBussy),NULL);
-   gtk_signal_connect(GTK_OBJECT(window),"destroy",
-                      GTK_SIGNAL_FUNC(gtk_widget_destroy),NULL);
+   g_signal_connect(window, "destroy",
+                      G_CALLBACK(XMdcExtractNotBussy),NULL);
+   g_signal_connect(window, "destroy",
+                      G_CALLBACK(gtk_widget_destroy),NULL);
 
    if (input->style == MDC_INPUT_NORM_STYLE) {
      gtk_window_set_title(GTK_WINDOW(window),"Extract Input Normal");
@@ -280,7 +281,7 @@ void XMdcGetImages(void)
    }
    gtk_container_set_border_width(GTK_CONTAINER(window),0);
 
-   box1 = gtk_vbox_new(FALSE,5);
+   box1 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
    gtk_container_add(GTK_CONTAINER(window),box1);
    gtk_container_set_border_width(GTK_CONTAINER(box1),5);
    gtk_widget_show(box1);
@@ -289,7 +290,7 @@ void XMdcGetImages(void)
    gtk_box_pack_start(GTK_BOX(box1),frame,TRUE,TRUE,0);
    gtk_widget_show(frame);
 
-   box2 = gtk_vbox_new(FALSE,5);
+   box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
    gtk_container_add(GTK_CONTAINER(frame),box2);
    gtk_container_set_border_width(GTK_CONTAINER(box2),5);
    gtk_widget_show(box2);
@@ -313,12 +314,12 @@ void XMdcGetImages(void)
      gtk_box_pack_start(GTK_BOX(box1),frame,TRUE,TRUE,0);
      gtk_widget_show(frame);
 
-     box2 = gtk_vbox_new(FALSE,0);
+     box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL,0);
      gtk_container_add(GTK_CONTAINER(frame),box2);
      gtk_container_set_border_width(GTK_CONTAINER(box2),0);
      gtk_widget_show(box2);
 
-     box3 = gtk_hbox_new(FALSE,0);
+     box3 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
      gtk_container_add(GTK_CONTAINER(box2),box3);
      gtk_container_set_border_width(GTK_CONTAINER(box3),0);
      gtk_widget_show(box3);
@@ -330,14 +331,11 @@ void XMdcGetImages(void)
      gtk_box_pack_start(GTK_BOX(box3),label,TRUE,TRUE,0);
      gtk_widget_show(label);
 
-     planes=gtk_entry_new_with_max_length(50);
+     planes=gtk_entry_new(); gtk_entry_set_max_length(GTK_ENTRY(planes), 50);
      MdcDebugPrint("rc-style name = %s",gtk_widget_get_name(planes));
      gtk_entry_set_text(GTK_ENTRY(planes),"0");
      gtk_editable_select_region(GTK_EDITABLE(planes),0,-1);
      gtk_box_pack_start(GTK_BOX(box3),planes,TRUE,TRUE,0);
-#ifdef GTKONE
-     gtk_widget_draw_default(planes);
-#endif
      gtk_widget_show(planes);
      sExtractSelection.InputPlanes=planes;
 
@@ -359,251 +357,110 @@ void XMdcGetImages(void)
      gtk_box_pack_start(GTK_BOX(box1),frame,TRUE,TRUE,0);
      gtk_widget_show(frame);
 
-     table = gtk_table_new (4, 3, FALSE);
-     gtk_container_add(GTK_CONTAINER(frame),table);
-     gtk_widget_show(table);
+     grid = gtk_grid_new();
+     gtk_container_add(GTK_CONTAINER(frame),grid);
+     gtk_widget_show(grid);
 
      label = gtk_label_new("Planes");
      gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
      gtk_widget_set_name (label, "FixedLabel");
-     gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,0,1);
+     gtk_grid_attach(GTK_GRID(grid),label,0,0,1,1);
      gtk_widget_show(label);
      sprintf(mdcbufr,"[1...%u]",my.fi->dim[3]);
      label = gtk_label_new(mdcbufr);
      gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
      gtk_widget_set_name (label, "FixedLabel");
-     gtk_table_attach_defaults(GTK_TABLE(table),label,1,2,0,1);
+     gtk_grid_attach(GTK_GRID(grid),label,1,0,1,1);
      gtk_widget_show(label);
-     planes = gtk_entry_new_with_max_length(50);
+     planes = gtk_entry_new(); gtk_entry_set_max_length(GTK_ENTRY(planes), 50);
      gtk_entry_set_text(GTK_ENTRY(planes),"0");
      gtk_editable_select_region(GTK_EDITABLE(planes),0,-1);
-     gtk_table_attach_defaults(GTK_TABLE(table),planes,2,3,0,1);
+     gtk_grid_attach(GTK_GRID(grid),planes,2,0,1,1);
      gtk_widget_show(planes);
      sExtractSelection.InputPlanes=planes;
 
      label = gtk_label_new("Frames");
      gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
      gtk_widget_set_name (label, "FixedLabel");
-     gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
+     gtk_grid_attach(GTK_GRID(grid),label,0,1,1,1);
      gtk_widget_show(label);
      sprintf(mdcbufr,"[1...%u]",my.fi->dim[4]);
      label = gtk_label_new(mdcbufr);
      gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
      gtk_widget_set_name (label, "FixedLabel");
-     gtk_table_attach_defaults(GTK_TABLE(table),label,1,2,1,2);
+     gtk_grid_attach(GTK_GRID(grid),label,1,1,1,1);
      gtk_widget_show(label);
-     frames = gtk_entry_new_with_max_length(50);
+     frames = gtk_entry_new(); gtk_entry_set_max_length(GTK_ENTRY(frames), 50);
      gtk_entry_set_text(GTK_ENTRY(frames),"0");
      gtk_editable_select_region(GTK_EDITABLE(frames),0,-1);
-     gtk_table_attach_defaults(GTK_TABLE(table),frames,2,3,1,2);
+     gtk_grid_attach(GTK_GRID(grid),frames,2,1,1,1);
      gtk_widget_show(frames);
      sExtractSelection.InputFrames=frames;
 
      label = gtk_label_new("Gates");
      gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
      gtk_widget_set_name (label, "FixedLabel");
-     gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,2,3);
+     gtk_grid_attach(GTK_GRID(grid),label,0,2,1,1);
      gtk_widget_show(label);
      sprintf(mdcbufr,"[1...%u]",my.fi->dim[5]);
      label = gtk_label_new(mdcbufr);
      gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
      gtk_widget_set_name (label, "FixedLabel");
-     gtk_table_attach_defaults(GTK_TABLE(table),label,1,2,2,3);
+     gtk_grid_attach(GTK_GRID(grid),label,1,2,1,1);
      gtk_widget_show(label);
-     gates = gtk_entry_new_with_max_length(50);
+     gates = gtk_entry_new(); gtk_entry_set_max_length(GTK_ENTRY(gates), 50);
      gtk_entry_set_text(GTK_ENTRY(gates),"0");
      gtk_editable_select_region(GTK_EDITABLE(gates),0,-1);
-     gtk_table_attach_defaults(GTK_TABLE(table),gates,2,3,2,3);
+     gtk_grid_attach(GTK_GRID(grid),gates,2,2,1,1);
      gtk_widget_show(gates);
      sExtractSelection.InputGates=gates;
 
      label = gtk_label_new("Beds");
      gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
      gtk_widget_set_name (label, "FixedLabel");
-     gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,3,4);
+     gtk_grid_attach(GTK_GRID(grid),label,0,3,1,1);
      gtk_widget_show(label);
      sprintf(mdcbufr,"[1...%u]",my.fi->dim[6]);
      label = gtk_label_new(mdcbufr);
      gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
      gtk_widget_set_name (label, "FixedLabel");
-     gtk_table_attach_defaults(GTK_TABLE(table),label,1,2,3,4);
+     gtk_grid_attach(GTK_GRID(grid),label,1,3,1,1);
      gtk_widget_show(label);
-     beds= gtk_entry_new_with_max_length(50);
+     beds= gtk_entry_new(); gtk_entry_set_max_length(GTK_ENTRY(beds), 50);
      gtk_entry_set_text(GTK_ENTRY(beds),"0");
      gtk_editable_select_region(GTK_EDITABLE(beds),0,-1);
-     gtk_table_attach_defaults(GTK_TABLE(table),beds,2,3,3,4);
+     gtk_grid_attach(GTK_GRID(grid),beds,2,3,1,1);
      gtk_widget_show(beds);
      sExtractSelection.InputBeds=beds;
 
-
    }
 
    /* create horizontal separator */
-   separator = gtk_hseparator_new();
+   separator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start(GTK_BOX(box1),separator,FALSE,FALSE,0);
    gtk_widget_show(separator);
 
    /* create bottom buttons */
-   box2 = gtk_hbox_new(FALSE,0);
+   box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
    gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,2);
    gtk_widget_show(box2);
 
    button = gtk_button_new_with_label("Apply");
    gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-   gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                      GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(window));
-   gtk_signal_connect(GTK_OBJECT(button),"clicked",
-                      GTK_SIGNAL_FUNC(XMdcGetImagesCallbackApply), NULL);
-   gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
-                      GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(window));
+   g_signal_connect_swapped(button, "clicked",
+                      G_CALLBACK(gtk_widget_hide), window);
+   g_signal_connect(button, "clicked",
+                      G_CALLBACK(XMdcGetImagesCallbackApply), NULL);
+   g_signal_connect_swapped(button, "clicked",
+                      G_CALLBACK(gtk_widget_destroy), window);
    gtk_widget_show(button);
 
    button = gtk_button_new_with_label("Cancel");
    gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 2);
-   gtk_signal_connect_object(GTK_OBJECT (button), "clicked",
-                      GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(window));
+   g_signal_connect_swapped(button, "clicked",
+                      G_CALLBACK(gtk_widget_destroy), window);
    gtk_widget_show(button);
 
    XMdcShowWidget(window);
 }
 
-void XMdcExtractStyleSelCallbackApply(GtkWidget *widget, gpointer data)
-{
-
-  MdcExtractInputStruct *input = sExtractSelection.input;
-
-  if (XMdcNoFileOpened()) return;
-
-  MdcDebugPrint("extract stype: ");
-  if (GTK_TOGGLE_BUTTON(sExtractSelection.NormStyle)->active) {
-    MdcDebugPrint("\tnormal");
-    input->style = MDC_INPUT_NORM_STYLE;
-  }else if (GTK_TOGGLE_BUTTON(sExtractSelection.EcatStyle)->active) {
-    MdcDebugPrint("\tecat");
-    input->style = MDC_INPUT_ECAT_STYLE;
-  }
-
-  XMdcGetImages();
-
-}
-
-
-
-void XMdcExtractStyleSel(GtkWidget *widget, gpointer data)
-{
-  GtkWidget *box1;
-  GtkWidget *box2;
-  GtkWidget *box3;
-  GtkWidget *box4;
-  GtkWidget *frame;
-  GtkWidget *button;
-  GtkWidget *separator;
-  GSList *group;
-  MdcExtractInputStruct *input = sExtractSelection.input;
-
-  if (XMdcNoFileOpened() || BUSSY) return;
-
-  if (wextract == NULL)  {
-
-    wextract = gtk_window_new(GTK_WINDOW_TOPLEVEL); BUSSY = MDC_YES;
-
-    gtk_signal_connect(GTK_OBJECT(wextract),"destroy",
-                       GTK_SIGNAL_FUNC(XMdcMedconQuit),NULL);
-    gtk_signal_connect(GTK_OBJECT(wextract),"delete_event",
-                       GTK_SIGNAL_FUNC(XMdcExtractNotBussy),NULL);
-    gtk_signal_connect(GTK_OBJECT(wextract),"delete_event",
-                       GTK_SIGNAL_FUNC(XMdcHandlerToHide),NULL);
-
-    gtk_window_set_title(GTK_WINDOW(wextract),"Extract Selection");
-
-    gtk_container_set_border_width (GTK_CONTAINER(wextract), 0);
-
-    box1 = gtk_vbox_new(FALSE,0);
-    gtk_container_add(GTK_CONTAINER(wextract),box1);
-    gtk_widget_show(box1);
-
-    /* create upper box - Extract Style */
-    box2 = gtk_vbox_new(FALSE, 5);
-    gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,0);
-    gtk_container_set_border_width(GTK_CONTAINER(box2),5);
-    gtk_widget_show(box2);
-
-    box3 = gtk_hbox_new(FALSE, 5);
-    gtk_box_pack_start(GTK_BOX(box2),box3,TRUE,TRUE,0);
-    gtk_widget_show(box3);
-
-    frame = gtk_frame_new("Extraction Style");
-    gtk_box_pack_start(GTK_BOX(box3),frame,TRUE,TRUE,0);
-    gtk_widget_show(frame);
-
-    box4 = gtk_vbox_new(FALSE,0);
-    gtk_container_add(GTK_CONTAINER(frame),box4);
-    gtk_container_set_border_width(GTK_CONTAINER(box4), 5);
-    gtk_widget_show(box4);
-
-    button = gtk_radio_button_new_with_label(NULL,"Normal");
-    gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
-    if (input->style == MDC_INPUT_NORM_STYLE)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
-    gtk_widget_show(button);
-    sExtractSelection.NormStyle=button;
-
-    group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
-    button= gtk_radio_button_new_with_label(group,"Ecat");
-    gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
-    if (input->style == MDC_INPUT_ECAT_STYLE)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
-    gtk_widget_show(button);
-    sExtractSelection.EcatStyle=button;
-
-    /* create horizontal separator */
-    separator = gtk_hseparator_new();
-    gtk_box_pack_start(GTK_BOX(box1),separator,FALSE,FALSE,0);
-    gtk_widget_show(separator);
-
-    /* create bottom button box */
-    box2 = gtk_hbox_new(FALSE,0);
-    gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,2);
-    gtk_widget_show(box2);
-
-    button = gtk_button_new_with_label("Apply");
-    gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-    gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
-                     GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(wextract));
-    gtk_signal_connect(GTK_OBJECT(button),"clicked",
-                     GTK_SIGNAL_FUNC(XMdcExtractStyleSelCallbackApply), NULL);
-    gtk_widget_show(button);
-
-    button = gtk_button_new_with_label("Cancel");
-    gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-    gtk_signal_connect(GTK_OBJECT(button),"clicked",
-                       GTK_SIGNAL_FUNC(XMdcExtractNotBussy), NULL);
-    gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
-            GTK_SIGNAL_FUNC(gtk_widget_hide),GTK_OBJECT(wextract));
-    gtk_widget_show(button);
-
-  }else{
-    GtkWidget *b1, *b2;
-
-    gtk_widget_hide(wextract);
-
-    b1 = sExtractSelection.NormStyle;
-    b2 = sExtractSelection.EcatStyle;
-
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1),FALSE);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b2),FALSE);
-    switch (sExtractSelection.input->style) {
-      case MDC_INPUT_NORM_STYLE:
-          gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1),TRUE); break;
-      case MDC_INPUT_ECAT_STYLE:
-          gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b2),TRUE); break;
-    }
-
-
-  }
-
-
-  XMdcShowWidget(wextract);
-
-}
-
