@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -39,9 +39,7 @@ void XMdcExtractImages(void);
 int  XMdcHandleEcatList(char *S,Uint32 **list,Uint32 max);
 int  XMdcHandleNormList(char *s,Uint32 **inrs,Uint32 *it,Uint32 *bt,Uint32 max);
 void XMdcGetImagesCallbackApply(GtkWidget *widget, gpointer data);
-void XMdcGetImages(void);
-void XMdcExtractStyleSelCallbackApply(GtkWidget *widget, gpointer data);
-void XMdcExtractStyleSel(GtkWidget *widget, gpointer data);
+void XMdcGetImages(GtkWidget *widget, guint style);
 
 #endif
 
