@@ -13,11 +13,11 @@
  *                XMdcNoFileOpened()       - Give message if no file open  *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -55,7 +55,7 @@
                             F U N C T I O N S
 ****************************************************************************/
 
-void XMdcDisplayFile(const char *fname)
+void XMdcDisplayFile(char *fname)
 {
   XMdcViewerHide();
   XMdcMainWidgetsInsensitive();
