@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -35,7 +35,7 @@
                             F U N C T I O N S
 ****************************************************************************/
 
-void XMdcDisplayFile(const char *fname);
+void XMdcDisplayFile(char *fname);
 void XMdcRereadFile(GtkWidget *widget, gpointer data);
 void XMdcCloseFile(GtkWidget *widget, gpointer data);
 int  XMdcNoFileOpened(void);
