@@ -9,18 +9,18 @@
  *                                                                         *
  * Functions    : XMdcRemovePreviousImages()   - Remove old X images       *
  *                XMdcImagesSetCursor()        - Set cursor over X images  *
- *                XMdcImagesCallbackExpose()   - Images Expose  callback   *
+ *                XMdcImagesCallbackDraw()     - Images Draw callback      *
  *                XMdcImagesCallbackClicked()  - Images Clicked callback   *
  *                XMdcBuildCurrentImages()     - Build images for display  *
  *                XMdcDisplayImages()          - Display the images        *
  *                XMdcImagesView()             - Show the images (viewer)  *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -48,67 +48,6 @@
                             F U N C T I O N S
 ****************************************************************************/
 
-#ifdef MDC_USE_SIGNAL_BLOCKER
-/*
- * MARK: dirty fix of bad button-press-event behaviour in _WIN32
- *
- * The button-press-events of our image's drawing areas seems to be
- * "propagated" over all our widgets ... We got for example zoom or info
- * windows by clicking on places we wouldn't expect this to happen.
- *
- * So we 're blocking this button-press-event whenever we leave the
- * corresponding drawing area (and ofcourse, reallowing when entering)
- *
- * However, the gtk_signal_handler_block() function increments a number
- * instead of using a simple boolean. Whenever the "enter_notify_event"
- * is missed ... this number will never drop to zero again. And it does
- * happen when widgets come in front of our drawing areas which are rebuild
- * because of a color correction or colormap change.
- *
- * Our SignalBlocker struct should prevent the gtk_signal_handler_block()
- * function being called several times ...
- *
- * Actual struct defined in xdefs.h:
-typedef struct SignalBlocker_t{
-
-  guint id;
-  gboolean blocked;
-
-}SignalBlocker;
- *
- */
-
-static gboolean XMdcSignalBlock(GtkWidget *widget, gpointer data)
-{
-  SignalBlocker *signal;
-
-  signal = (SignalBlocker *)gtk_object_get_data(GTK_OBJECT(widget),"signal");
-
-  if (!signal->blocked) {
-    gtk_signal_handler_block(GTK_OBJECT(widget),signal->id);
-    signal->blocked = TRUE;
-  }
-
-  return(TRUE);
-
-}
-
-static gboolean XMdcSignalUnblock(GtkWidget *widget, gpointer data)
-{
-  SignalBlocker *signal;
-
-  signal = (SignalBlocker *)gtk_object_get_data(GTK_OBJECT(widget),"signal");
-
-  if (signal->blocked) {
-    gtk_signal_handler_unblock(GTK_OBJECT(widget),signal->id);
-    signal->blocked = FALSE;
-  }
-
-  return(TRUE);
-
-}
-#endif
-
 void XMdcRemovePreviousImages(void)
 {
   Uint32 i;
@@ -121,43 +60,39 @@ void XMdcRemovePreviousImages(void)
 
 void XMdcImagesSetCursor(GtkWidget *widget, gpointer data)
 {
-  if (widget->window != NULL)
-    gdk_window_set_cursor (widget->window, handcursor);
+  GdkWindow *window = gtk_widget_get_window(widget);
+
+  if (window != NULL)
+    gdk_window_set_cursor (window, handcursor);
 }
 
 
-gboolean XMdcImagesCallbackExpose(GtkWidget *widget, GdkEventExpose *event, Uint32 *nr)
+gboolean XMdcImagesCallbackDraw(GtkWidget *widget, GdkEventExpose *event, Uint32 *nr)
 {
-  GdkGC *gc = widget->style->white_gc;
+  GdkWindow *window;
+  GdkDrawingContext *draw_context;
+  cairo_region_t *cairo_region;
+  cairo_t *cr;
+
   Uint32 i = (Uint32)(*nr);
-  gint ex, ey, ew, eh, iw, ih, rw, rh;
 
   if ( my.im[i] == NULL ) return(TRUE);
 
-  /* repaint the polluted drawable */
-  iw = gdk_pixbuf_get_width(my.im[i]);
-  ih = gdk_pixbuf_get_height(my.im[i]);
+  window = gtk_widget_get_window(widget);
 
-  ex = event->area.x;     ey = event->area.y;
-  ew = event->area.width; eh = event->area.height;
+  cairo_region = cairo_region_create();
 
-  if ((ex < iw) && (ey < ih)) {
-    rw = iw - ex; rh = ih - ey;
-    gdk_pixbuf_render_to_drawable(my.im[i], widget->window, gc,
-                                  ex, ey, ex, ey, rw, rh,
-                                  sRenderSelection.Dither, 0, 0);
-  }
+  draw_context = gdk_window_begin_draw_frame(window, cairo_region);
+  cr = gdk_drawing_context_get_cairo_context(draw_context);
 
-  if ((ex + ew) > iw) {
-    rw = (ex + ew) - iw; rh = eh;
-    gdk_window_clear_area(widget->window, iw, ey, rw, rh);
+  /* repaint the polluted cairo context */
+  gdk_cairo_set_source_pixbuf(cr, my.im[i], 0, 0);
+  cairo_paint(cr);
 
-  }
-  if ((ey + eh) > ih) {
-    rh = (ey + eh) - ih; rw = ew;
-    gdk_window_clear_area(widget->window, ex, ih, rw, rh);
-  }
+  gdk_window_end_draw_frame(window, draw_context);
+  cairo_region_destroy(cairo_region);
 
+  /* print labels */
   if (sLabelSelection.CurState == MDC_YES) {
     XMdcPrintImageLabelIndex(widget,i);
     XMdcPrintImageLabelTimes(widget,i);
@@ -222,10 +157,6 @@ void XMdcBuildCurrentImages(void)
   for (r=0; r<my.images_vertical; r++)
   for (c=0; c<my.images_horizontal; c++,i++, ri++) {
 
-#ifdef MDC_USE_SIGNAL_BLOCKER
-     SignalBlocker *signal = (SignalBlocker *)&my.sblkr[ri];
-#endif
-
      progress += 1./(float)(my.real_images_on_page + 1);
 
      if (ri == my.real_images_on_page) break; /* get OUT, got all images */
@@ -238,7 +169,7 @@ void XMdcBuildCurrentImages(void)
 
        my.image[ri] = gtk_drawing_area_new();
 
-       gtk_drawing_area_size(GTK_DRAWING_AREA(my.image[ri])
+       gtk_widget_set_size_request(my.image[ri]
            ,(gint)(XMdcScaleW(my.fi->mwidth)  + XMDC_IMAGE_BORDER)
            ,(gint)(XMdcScaleH(my.fi->mheight) + XMDC_IMAGE_BORDER));
 
@@ -250,32 +181,16 @@ void XMdcBuildCurrentImages(void)
 #endif
            );
 
-       gtk_table_attach(GTK_TABLE(my.imgstable),my.image[ri],c,c+1,r,r+1,
-                        GTK_FILL,GTK_FILL, 0, 0);
+       gtk_grid_attach(GTK_GRID(my.imgsgrid),my.image[ri],c,r,1,1);
 
-#ifdef MDC_USE_SIGNAL_BLOCKER
-       signal->id =
-#endif
-       gtk_signal_connect (GTK_OBJECT(my.image[ri]), "button_press_event",
-                           GTK_SIGNAL_FUNC(XMdcImagesCallbackClicked),
+       g_signal_connect (my.image[ri], "button_press_event",
+                           G_CALLBACK(XMdcImagesCallbackClicked),
                            (Uint32 *)&my.imagenumber[ri]);
 
-       gtk_signal_connect (GTK_OBJECT(my.image[ri]),"expose_event",
-                           GTK_SIGNAL_FUNC(XMdcImagesCallbackExpose),
+       g_signal_connect (my.image[ri], "draw",
+                           G_CALLBACK(XMdcImagesCallbackDraw),
                            (Uint32 *)&my.imagenumber[ri]);
 
-#ifdef MDC_USE_SIGNAL_BLOCKER
-       gtk_signal_connect (GTK_OBJECT(my.image[ri]),"enter_notify_event",
-           GTK_SIGNAL_FUNC(XMdcSignalUnblock), NULL);
-
-       gtk_signal_connect (GTK_OBJECT(my.image[ri]),"leave_notify_event",
-           GTK_SIGNAL_FUNC(XMdcSignalBlock), NULL);
-
-       gtk_object_set_data(GTK_OBJECT(my.image[ri]),"signal",signal);
-
-       XMdcSignalBlock(my.image[ri],NULL);
-#endif
-
        XMdcImagesSetCursor(my.image[ri],NULL);
 
      }
@@ -283,7 +198,7 @@ void XMdcBuildCurrentImages(void)
      gtk_widget_show(my.image[ri]);
 
 
-     if (GTK_WIDGET_VISIBLE(my.viewwindow)) {
+     if (gtk_widget_get_visible(my.viewwindow)) {
        if (my.images_horizontal < 10) {
          /* update after each two rows */
          if (((ri+1)%(my.images_horizontal*2)) == 0)
@@ -300,6 +215,22 @@ void XMdcBuildCurrentImages(void)
   }
 }
 
+void XMdcSetFixedImagesGridSize(void)
+{
+  /* MARK: table() preserved fixed size ... grid() doesn't,
+   * MARK: but needed to keep buttons on the same place */
+  gint wcel, hcel, wfixed, hfixed;
+
+  wcel = XMdcScaleW(my.fi->mwidth)  + XMDC_IMAGE_BORDER;
+  wfixed = wcel * my.images_horizontal;
+
+  hcel = XMdcScaleH(my.fi->mheight) + XMDC_IMAGE_BORDER;
+  hfixed = hcel * my.images_vertical;
+
+  gtk_widget_set_size_request(my.imgsbox, wfixed, hfixed);
+
+}
+
 void XMdcDisplayImages(void)
 {
   XMdcProgressBar(MDC_PROGRESS_BEGIN,0.,"Preparing Viewer:");
@@ -310,8 +241,7 @@ void XMdcDisplayImages(void)
   XMdcBuildColorMap();
   XMdcBuildCurrentImages();
   XMdcResizeNeeded();
-  gtk_container_foreach(GTK_CONTAINER(my.imgstable),
-                          (GtkCallback)XMdcImagesSetCursor,NULL);
+  XMdcSetFixedImagesGridSize();
 }
 
 void XMdcImagesView(GtkWidget *widget, gpointer data)
