@@ -18,11 +18,11 @@
  *                XMdcLabelSel()                - Label selection          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -143,87 +143,107 @@ char *XMdcGetImageLabelTimes(Uint32 nr)
 
 void XMdcPrintImageLabelIndex(GtkWidget *widget, Uint32 nr)
 {
-  GdkColormap *map = gtk_widget_get_colormap(widget);
+  GdkWindow *window;
+  GdkDrawingContext *draw_context;
+  cairo_region_t *cairo_region;
+  cairo_t *cr;
   char *label;
 
-  /* first, create a GC to draw on */
-  sLabelSelection.gc = gdk_gc_new(widget->window);
+  window = gtk_widget_get_window(widget);
 
+  cairo_region = cairo_region_create();
+
+  /* begin drawing */
+  draw_context = gdk_window_begin_draw_frame(window, cairo_region);
+  cr = gdk_drawing_context_get_cairo_context(draw_context);
+
+  /* set font */
+  cairo_select_font_face(cr, "monospace", CAIRO_FONT_SLANT_ITALIC, CAIRO_FONT_WEIGHT_NORMAL);
+  cairo_set_font_size(cr, 11);
+
+  /* set color */
   switch (sLabelSelection.CurColor) {
-    case XMDC_LABEL_RED   : sLabelSelection.color = &Red; break;
-    case XMDC_LABEL_GREEN : sLabelSelection.color = &Green; break;
-    case XMDC_LABEL_BLUE  : sLabelSelection.color = &Blue; break;
-    case XMDC_LABEL_YELLOW: sLabelSelection.color = &Yellow; break;
+    case XMDC_LABEL_RED   : cairo_set_source_rgb(cr, 1, 0, 0); break;
+    case XMDC_LABEL_GREEN : cairo_set_source_rgb(cr, 0, 1, 0); break;
+    case XMDC_LABEL_BLUE  : cairo_set_source_rgb(cr, 0, 0, 1); break;
+    case XMDC_LABEL_YELLOW: cairo_set_source_rgb(cr, 1, 1, 0); break; 
   }
 
+  /* show label */
+  label = XMdcGetImageLabelIndex(nr);
+  cairo_move_to(cr, 2.0, (double)XMdcScaleH(my.fi->mheight) - 2.0);
+  cairo_show_text(cr, label);
 
-  /* set the foreground to our color */
-  gdk_colormap_alloc_color(map,sLabelSelection.color, FALSE, TRUE);
-  gdk_gc_set_foreground(sLabelSelection.gc, sLabelSelection.color);
+  /* end drawing */
+  gdk_window_end_draw_frame(window, draw_context);
+  cairo_region_destroy(cairo_region);
 
-  label=XMdcGetImageLabelIndex(nr);
-
-  gdk_draw_string(widget->window, sfixed, sLabelSelection.gc
-      , 2, (gint)(XMdcScaleH(my.fi->mheight)-2), label);
-
-  gdk_colormap_free_colors(map,sLabelSelection.color,1);
-  gdk_gc_destroy(sLabelSelection.gc);
 }
 
 void XMdcPrintImageLabelTimes(GtkWidget *widget, Uint32 nr)
 {
-  GdkColormap *map = gtk_widget_get_colormap(widget);
+  GdkWindow *window;
+  GdkDrawingContext *draw_context;
+  cairo_region_t *cairo_region;
+  cairo_t *cr;
   char *label;
 
-  /* first, create a GC to draw on */
-  sLabelSelection.gc = gdk_gc_new(widget->window);
+  window = gtk_widget_get_window(widget);
+
+  cairo_region = cairo_region_create();
+
+  /* begin drawing */
+  draw_context = gdk_window_begin_draw_frame(window, cairo_region);
+  cr = gdk_drawing_context_get_cairo_context(draw_context);
+
+  /* set font */
+  cairo_select_font_face(cr, "monospace", CAIRO_FONT_SLANT_ITALIC, CAIRO_FONT_WEIGHT_NORMAL);
+  cairo_set_font_size(cr, 11);
 
   switch (sLabelSelection.CurColor) {
-    case XMDC_LABEL_RED   : sLabelSelection.color = &Red; break;
-    case XMDC_LABEL_GREEN : sLabelSelection.color = &Green; break;
-    case XMDC_LABEL_BLUE  : sLabelSelection.color = &Blue; break;
-    case XMDC_LABEL_YELLOW: sLabelSelection.color = &Yellow; break;
+    case XMDC_LABEL_RED   : cairo_set_source_rgb(cr, 1, 0, 0); break;
+    case XMDC_LABEL_GREEN : cairo_set_source_rgb(cr, 0, 1, 0); break;
+    case XMDC_LABEL_BLUE  : cairo_set_source_rgb(cr, 0, 0, 1); break;
+    case XMDC_LABEL_YELLOW: cairo_set_source_rgb(cr, 1, 1, 0); break;
   }
 
+  /* show label */
+  label = XMdcGetImageLabelTimes(nr);
+  cairo_move_to(cr, 2.0, 10.0);
+  cairo_show_text(cr, label);
 
-  /* set the foreground to our color */
-  gdk_colormap_alloc_color(map,sLabelSelection.color, FALSE, TRUE);
-  gdk_gc_set_foreground(sLabelSelection.gc, sLabelSelection.color);
+  /* end drawing */
+  gdk_window_end_draw_frame(window, draw_context);
+  cairo_region_destroy(cairo_region);
 
-  label=XMdcGetImageLabelTimes(nr);
-
-  gdk_draw_string(widget->window, sfixed, sLabelSelection.gc, 2, 10, label);
-
-  gdk_colormap_free_colors(map,sLabelSelection.color,1);
-  gdk_gc_destroy(sLabelSelection.gc);
 }
 
 void XMdcLabelSelCallbackApply(GtkWidget *widget, gpointer data)
 {
   gint color=XMDC_LABEL_YELLOW, state=MDC_YES, style=XMDC_LABEL_STYLE_PAGE;
-  if (GTK_TOGGLE_BUTTON(sLabelSelection.On)->active) {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sLabelSelection.On))) {
     MdcDebugPrint("labels: ON "); state = MDC_YES;
-  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.Off)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sLabelSelection.Off))) {
     MdcDebugPrint("labels: OFF "); state = MDC_NO;
   }
 
   MdcDebugPrint("label color: ");
-  if (GTK_TOGGLE_BUTTON(sLabelSelection.Red)->active) {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sLabelSelection.Red))) {
     MdcDebugPrint("\tred"); color = XMDC_LABEL_RED;
-  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.Green)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sLabelSelection.Green))) {
     MdcDebugPrint("\tgreen"); color = XMDC_LABEL_GREEN;
-  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.Blue)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sLabelSelection.Blue))) {
     MdcDebugPrint("\tblue"); color = XMDC_LABEL_BLUE;
-  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.Yellow)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sLabelSelection.Yellow))) {
     MdcDebugPrint("\tyellow"); color = XMDC_LABEL_YELLOW;
   }
 
   MdcDebugPrint("label number: ");
-  if (GTK_TOGGLE_BUTTON(sLabelSelection.NrAbsolute)->active) {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sLabelSelection.NrAbsolute))) {
     MdcDebugPrint("\tabsolute"); style = XMDC_LABEL_STYLE_ABS;
-  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.NrInPage)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sLabelSelection.NrInPage))) {
     MdcDebugPrint("\tin page");  style = XMDC_LABEL_STYLE_PAGE;
-  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.NrEcat)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sLabelSelection.NrEcat))) {
     MdcDebugPrint("\tecat");     style = XMDC_LABEL_STYLE_ECAT;
   }
 
@@ -266,26 +286,26 @@ void XMdcLabelSel(void)
   if (wlabel == NULL) {
     wlabel = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-    gtk_signal_connect(GTK_OBJECT(wlabel),"destroy",
-                       GTK_SIGNAL_FUNC(XMdcMedconQuit), NULL);
-    gtk_signal_connect(GTK_OBJECT(wlabel),"delete_event",
-                       GTK_SIGNAL_FUNC(XMdcHandlerToHide), NULL);
+    g_signal_connect(wlabel, "destroy",
+                       G_CALLBACK(XMdcMedconQuit), NULL);
+    g_signal_connect(wlabel, "delete_event",
+                       G_CALLBACK(XMdcHandlerToHide), NULL);
 
 
     gtk_window_set_title(GTK_WINDOW(wlabel),"Label Selection");
     gtk_container_set_border_width(GTK_CONTAINER(wlabel),0);
 
-    box1 = gtk_vbox_new(FALSE,0);
+    box1 = gtk_box_new(GTK_ORIENTATION_VERTICAL,0);
     gtk_container_add(GTK_CONTAINER(wlabel),box1);
     gtk_widget_show(box1);
 
     /* create upper box - label */
-    box2 = gtk_vbox_new(FALSE, 5);
+    box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
     gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,0);
     gtk_container_set_border_width(GTK_CONTAINER(box2), 5);
     gtk_widget_show(box2);
 
-    box3 = gtk_hbox_new(FALSE, 5);
+    box3 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
     gtk_box_pack_start(GTK_BOX(box2),box3,TRUE,TRUE,0);
     gtk_widget_show(box3);
 
@@ -294,7 +314,7 @@ void XMdcLabelSel(void)
     gtk_box_pack_start(GTK_BOX(box3),frame,TRUE,TRUE,0);
     gtk_widget_show(frame);
 
-    box4 = gtk_vbox_new(FALSE,0);
+    box4 = gtk_box_new(GTK_ORIENTATION_VERTICAL,0);
     gtk_container_add(GTK_CONTAINER(frame),box4);
     gtk_container_set_border_width(GTK_CONTAINER(box4),5);
     gtk_widget_show(box4);
@@ -304,28 +324,18 @@ void XMdcLabelSel(void)
     gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
     if (sLabelSelection.CurState == MDC_YES)
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-#ifdef GTKONE
-    gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
-                       GTK_SIGNAL_FUNC(XMdcSensitiveColNumFrames),NULL);
-#else
-    gtk_signal_connect(GTK_OBJECT(button),"toggled",
-                       GTK_SIGNAL_FUNC(XMdcSensitiveColNumFrames),NULL);
-#endif
+    g_signal_connect(button, "toggled",
+                       G_CALLBACK(XMdcSensitiveColNumFrames),NULL);
     gtk_widget_show(button);
     sLabelSelection.On = button;
 
-    group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group,"OFF");
     gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
     if (sLabelSelection.CurState == MDC_NO)
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-#ifdef GTKONE
-    gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
-                       GTK_SIGNAL_FUNC(XMdcUnsensitiveColNumFrames),NULL);
-#else
-    gtk_signal_connect(GTK_OBJECT(button),"toggled",
-                       GTK_SIGNAL_FUNC(XMdcUnsensitiveColNumFrames),NULL);
-#endif
+    g_signal_connect(button, "toggled",
+                       G_CALLBACK(XMdcUnsensitiveColNumFrames),NULL);
     gtk_widget_show(button);
     sLabelSelection.Off = button;
     /* create label colors frame */
@@ -333,7 +343,7 @@ void XMdcLabelSel(void)
     gtk_box_pack_start(GTK_BOX(box3),frame,TRUE,TRUE,0);
     gtk_widget_show(frame);
 
-    box4 = gtk_vbox_new(FALSE,0);
+    box4 = gtk_box_new(GTK_ORIENTATION_VERTICAL,0);
     gtk_container_add(GTK_CONTAINER(frame),box4);
     gtk_container_set_border_width(GTK_CONTAINER(box4), 10);
     gtk_widget_show(box4);
@@ -346,7 +356,7 @@ void XMdcLabelSel(void)
     gtk_widget_show(button);
     sLabelSelection.Red = button;
 
-    group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group,"Green");
     gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
     if (sLabelSelection.CurColor == XMDC_LABEL_GREEN)
@@ -354,7 +364,7 @@ void XMdcLabelSel(void)
     gtk_widget_show(button);
     sLabelSelection.Green = button;
 
-    group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group,"Blue");
     gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
     if (sLabelSelection.CurColor == XMDC_LABEL_BLUE)
@@ -362,7 +372,7 @@ void XMdcLabelSel(void)
     gtk_widget_show(button);
     sLabelSelection.Blue = button;
 
-    group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group,"Yellow");
     gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
     if (sLabelSelection.CurColor == XMDC_LABEL_YELLOW)
@@ -375,7 +385,7 @@ void XMdcLabelSel(void)
     gtk_box_pack_start(GTK_BOX(box3),frame,TRUE,TRUE,0);
     gtk_widget_show(frame);
 
-    box4 = gtk_vbox_new(FALSE,0);
+    box4 = gtk_box_new(GTK_ORIENTATION_VERTICAL,0);
     gtk_container_add(GTK_CONTAINER(frame),box4);
     gtk_container_set_border_width(GTK_CONTAINER(box4), 10);
     gtk_widget_show(box4);
@@ -388,7 +398,7 @@ void XMdcLabelSel(void)
     gtk_widget_show(button);
     sLabelSelection.NrAbsolute = button;
 
-    group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group,"In Page");
     gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
     if (sLabelSelection.CurStyle == XMDC_LABEL_STYLE_PAGE)
@@ -396,7 +406,7 @@ void XMdcLabelSel(void)
     gtk_widget_show(button);
     sLabelSelection.NrInPage = button;
 
-    group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+    group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     button = gtk_radio_button_new_with_label(group,"Ecat/Matrix");
     gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
     if (sLabelSelection.CurStyle == XMDC_LABEL_STYLE_ECAT)
@@ -405,27 +415,27 @@ void XMdcLabelSel(void)
     sLabelSelection.NrEcat = button;
 
     /* create horizontal separator */
-    separator = gtk_hseparator_new();
+    separator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_box_pack_start(GTK_BOX(box1),separator, FALSE, FALSE, 0);
     gtk_widget_show(separator);
 
     /* create bottom button box */
-    box2 = gtk_hbox_new(FALSE,0);
+    box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
     gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,2);
     gtk_widget_show(box2);
 
     button = gtk_button_new_with_label("Apply");
     gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-    gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                       GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(wlabel));
-    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                       GTK_SIGNAL_FUNC(XMdcLabelSelCallbackApply), NULL);
+    g_signal_connect_swapped(button, "clicked",
+                       G_CALLBACK(gtk_widget_hide), wlabel);
+    g_signal_connect(button, "clicked",
+                       G_CALLBACK(XMdcLabelSelCallbackApply), NULL);
     gtk_widget_show(button);
 
     button = gtk_button_new_with_label("Cancel");
     gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-    gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-        GTK_SIGNAL_FUNC(gtk_widget_hide),GTK_OBJECT(wlabel));
+    g_signal_connect_swapped(button, "clicked",
+        G_CALLBACK(gtk_widget_hide), wlabel);
     gtk_widget_show(button);
 
   }else{
