@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -36,13 +36,10 @@
 ****************************************************************************/
 
 #include <gdk/gdk.h>
-#include <gdk/gdkprivate.h>
 #include <gtk/gtk.h>
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#define __M_XDUMMY_H__ 1
-
 #include "medcon.h"
 #include "xicons.h"
 #include "xerror.h"
