@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -35,11 +35,11 @@
                             F U N C T I O N S
 ****************************************************************************/
 
-void XMdcPagesSelected(GtkWidget *widget, Uint32 *pagenr);
-gboolean XMdcPagesGoTo(GtkWidget *spinner, gpointer data);
+void XMdcPagesCbSelected(GtkWidget *widget, gpointer data);
+gboolean XMdcPagesCbGoTo(GtkWidget *spinner, gpointer data);
 GtkWidget *XMdcPagesCreateMenu(void);
-void XMdcPagesNext(void);
-void XMdcPagesPrev(void);
+void XMdcPagesCbNext(GtkWidget *widget, gpointer data);
+void XMdcPagesCbPrev(GtkWidget *widget, gpointer data);
 void XMdcPagesSelCallbackApply(GtkWidget *widget, gpointer data);
 void XMdcPagesSel(void);
 Uint32 XMdcPagesGetNrImages(void);
