@@ -20,11 +20,11 @@
  *                XMdcGetHeaderInfo()             - Ask Hdr Info           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -74,7 +74,7 @@ static MdcRawPrevInputStruct *prev = &mdcrawprevinput;
                             F U N C T I O N S
 ****************************************************************************/
 
-int XMdcReadFile(const char *fname)
+int XMdcReadFile(char *fname)
 {
 
   if (MdcOpenFile(my.fi,fname) != MDC_OK) {
@@ -150,41 +150,31 @@ void XMdcRawReadFinish(guint otype)
 
 }
 
-void XMdcRawReadInteractive(GtkWidget *fs)
+void XMdcRawReadInteractive(char *fname)
 {
-  const char *fname;
 
   XMdcMainWidgetsInsensitive();
 
-  gtk_widget_hide(fs);
-
   XMdcViewerHide();
 
   XMdcFileReset();
 
-  fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
-
   MdcInitFI(my.fi, fname);
 
   XMdcGetHeaderInfo();
 }
 
-void XMdcRawReadPredef(GtkWidget *fs)
+void XMdcRawReadPredef(char *fname)
 {
   IMG_DATA *id;
   Uint32 i;
-  const char *fname;
 
   XMdcMainWidgetsInsensitive();
 
-  gtk_widget_hide(fs);
-
   XMdcViewerHide();
 
   XMdcFileReset();
 
-  fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
-
   MdcInitFI(my.fi, fname);
 
   /* fill in input struct with predef values */
@@ -234,31 +224,31 @@ void XMdcRawReadCancel(guint otype)
 Int16 XMdcGetImageInfoPixelType(void)
 {
   MdcDebugPrint("pixel type: ");
-  if (GTK_TOGGLE_BUTTON(raw->typeBIT1)->active) {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeBIT1))) {
     MdcDebugPrint("\tBIT1"); return(BIT1);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeASCII)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeASCII))) {
     MdcDebugPrint("\tASCII"); return(ASCII);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeBIT8_S)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeBIT8_S))) {
     MdcDebugPrint("\tBIT8_S"); return(BIT8_S);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeBIT8_U)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeBIT8_U))) {
     MdcDebugPrint("\tBIT8_U"); return(BIT8_U);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeBIT16_S)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeBIT16_S))) {
     MdcDebugPrint("\tBIT16_S"); return(BIT16_S);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeBIT16_U)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeBIT16_U))) {
     MdcDebugPrint("\tBIT16_U"); return(BIT16_U);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeBIT32_S)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeBIT32_S))) {
     MdcDebugPrint("\tBIT32_S"); return(BIT32_S);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeBIT32_U)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeBIT32_U))) {
     MdcDebugPrint("\tBT32_U"); return(BIT32_U);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeBIT64_S)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeBIT64_S))) {
     MdcDebugPrint("\tBIT64_S"); return(BIT64_S);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeBIT64_U)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeBIT64_U))) {
     MdcDebugPrint("\tBIT64_U"); return(BIT64_U);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeFLT32)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeFLT32))) {
     MdcDebugPrint("\tFLT32"); return(FLT32);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeFLT64)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeFLT64))) {
     MdcDebugPrint("\tFLT64"); return(FLT64);
-  }else if (GTK_TOGGLE_BUTTON(raw->typeCOLRGB)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->typeCOLRGB))) {
     MdcDebugPrint("\tRGB"); return(COLRGB);
   }else{
     XMdcDisplayFatalErr(MDC_BAD_CODE,"Unknown pixeltype encountered");
@@ -344,7 +334,7 @@ void XMdcGetImageInfo(void)
   GtkWidget *window=NULL;
   GtkWidget *box1;
   GtkWidget *box2;
-  GtkWidget *table;
+  GtkWidget *grid;
   GtkWidget *frame;
   GtkWidget *label;
   GtkWidget *button;
@@ -353,13 +343,12 @@ void XMdcGetImageInfo(void)
   GSList *group;
 
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  gtk_signal_connect(GTK_OBJECT(window),"destroy",
-                     GTK_SIGNAL_FUNC(gtk_widget_destroy),NULL);
+  g_signal_connect(window, "destroy",
+                     G_CALLBACK(gtk_widget_destroy),NULL);
   gtk_window_set_title(GTK_WINDOW(window),"Input Image Info");
-  gtk_widget_set_uposition(window,10,10);
   gtk_container_set_border_width(GTK_CONTAINER(window), 0);
 
-  box1 = gtk_vbox_new(FALSE, 0);
+  box1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add(GTK_CONTAINER(window),box1);
   gtk_container_set_border_width(GTK_CONTAINER(box1), 0);
   gtk_widget_show(box1);
@@ -379,26 +368,28 @@ void XMdcGetImageInfo(void)
   gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
   gtk_widget_show(frame);
 
-  box2 = gtk_vbox_new(FALSE,5);
+  box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
   gtk_container_add(GTK_CONTAINER(frame),box2);
   gtk_container_set_border_width(GTK_CONTAINER(box2), 5);
   gtk_widget_show(box2);
 
 
-  table = gtk_table_new(1,2,FALSE);
-  gtk_container_add(GTK_CONTAINER(box2),table);
-  gtk_widget_show(table);
+  grid = gtk_grid_new();
+  gtk_container_add(GTK_CONTAINER(box2),grid);
+  gtk_widget_show(grid);
 
   label = gtk_label_new(" Offset in bytes ");
   gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
   gtk_widget_set_name(label, "FixedLabel");
-  gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,0,1);
+  gtk_grid_attach(GTK_GRID(grid),label,0,0,1,1);
   gtk_widget_show(label);
-  entry = gtk_entry_new_with_max_length(10);
+
+  entry = gtk_entry_new();
+  gtk_entry_set_max_length(GTK_ENTRY(entry), 10);
   sprintf(xmdcstr,"%u",prev->ABSHDR);
   gtk_entry_set_text(GTK_ENTRY(entry),xmdcstr);
   gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-  gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,0,1);
+  gtk_grid_attach(GTK_GRID(grid),entry,1,0,1,1);
   gtk_widget_show(entry);
   raw->AbsOffset = entry;
 
@@ -409,40 +400,44 @@ void XMdcGetImageInfo(void)
   gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
   gtk_widget_show(frame);
 
-  box2 = gtk_vbox_new(FALSE,5);
+  box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
   gtk_container_add(GTK_CONTAINER(frame),box2);
   gtk_container_set_border_width(GTK_CONTAINER(box2),5);
   gtk_widget_show(box2);
 
-  table = gtk_table_new(2,2,FALSE);
-  gtk_container_add(GTK_CONTAINER(box2),table);
-  gtk_widget_show(table);
+  grid = gtk_grid_new();
+  gtk_container_add(GTK_CONTAINER(box2),grid);
+  gtk_widget_show(grid);
 
   label = gtk_label_new(" Columns ");
   gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
   gtk_widget_set_name (label, "FixedLabel");
-  gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,0,1);
+  gtk_grid_attach(GTK_GRID(grid),label,0,0,1,1);
   gtk_widget_show(label);
-  entry = gtk_entry_new_with_max_length(5);
+ 
+  entry = gtk_entry_new();
+  gtk_entry_set_max_length(GTK_ENTRY(entry), 5);
   sprintf(xmdcstr,"%u",prev->XDIM);
   gtk_entry_set_text(GTK_ENTRY(entry),xmdcstr);
 
   gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-  gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,0,1);
+  gtk_grid_attach(GTK_GRID(grid),entry,1,0,1,1); 
   gtk_widget_show(entry);
   raw->ImgWidth = entry;
 
   label = gtk_label_new("   Rows ");
   gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
   gtk_widget_set_name (label, "FixedLabel");
-  gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
+  gtk_grid_attach(GTK_GRID(grid),label,0,1,1,1);
   gtk_widget_show(label);
-  entry = gtk_entry_new_with_max_length(5);
+
+  entry = gtk_entry_new();
+  gtk_entry_set_max_length(GTK_ENTRY(entry), 5);
   sprintf(xmdcstr,"%u",prev->YDIM);
   gtk_entry_set_text(GTK_ENTRY(entry),xmdcstr);
 
   gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-  gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,1,2);
+  gtk_grid_attach(GTK_GRID(grid),entry,1,1,1,1);
   gtk_widget_show(entry);
   raw->ImgHeight = entry;
 
@@ -452,113 +447,113 @@ void XMdcGetImageInfo(void)
   gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
   gtk_widget_show(frame);
 
-  box2 = gtk_vbox_new(FALSE,5);
+  box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
   gtk_container_add(GTK_CONTAINER(frame),box2);
   gtk_container_set_border_width(GTK_CONTAINER(box2),5);
   gtk_widget_show(box2);
 
-  table = gtk_table_new(7,2,FALSE);
-  gtk_container_add(GTK_CONTAINER(box2),table);
-  gtk_widget_show(table);
+  grid = gtk_grid_new();
+  gtk_container_add(GTK_CONTAINER(box2),grid);
+  gtk_widget_show(grid);
 
   button = gtk_radio_button_new_with_label(NULL,"1-bit");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,0,1,0,1);
+  gtk_grid_attach(GTK_GRID(grid),button,0,0,1,1);
   if (prev->PTYPE == BIT1) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
   gtk_widget_show(button);
   raw->typeBIT1=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"ASCII");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,1,2,0,1);
+  gtk_grid_attach(GTK_GRID(grid),button,1,0,1,1);
   if (prev->PTYPE == ASCII) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
   gtk_widget_show(button);
   raw->typeASCII=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"Int8");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,0,1,1,2);
+  gtk_grid_attach(GTK_GRID(grid),button,0,1,1,1);
   if (prev->PTYPE == BIT8_S) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
   gtk_widget_show(button);
   raw->typeBIT8_S=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"Uint8");
   if (prev->PTYPE == BIT8_U) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
-  gtk_table_attach_defaults(GTK_TABLE(table),button,1,2,1,2);
+  gtk_grid_attach(GTK_GRID(grid),button,1,1,1,1);
   gtk_widget_show(button);
   raw->typeBIT8_U=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"Int16");
   if (prev->PTYPE == BIT16_S) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
-  gtk_table_attach_defaults(GTK_TABLE(table),button,0,1,2,3);
+  gtk_grid_attach(GTK_GRID(grid),button,0,2,1,1);
   gtk_widget_show(button);
   raw->typeBIT16_S=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"Uint16");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,1,2,2,3);
+  gtk_grid_attach(GTK_GRID(grid),button,1,2,1,1);
   if (prev->PTYPE == BIT16_U) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
   gtk_widget_show(button);
   raw->typeBIT16_U=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"Int32");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,0,1,3,4);
+  gtk_grid_attach(GTK_GRID(grid),button,0,3,1,1);
   if (prev->PTYPE == BIT32_S) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
   gtk_widget_show(button);
   raw->typeBIT32_S=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"Uint32");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,1,2,3,4);
+  gtk_grid_attach(GTK_GRID(grid),button,1,3,1,1);
   if (prev->PTYPE == BIT32_U) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
   gtk_widget_show(button);
   raw->typeBIT32_U=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"Int64");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,0,1,4,5);
+  gtk_grid_attach(GTK_GRID(grid),button,0,4,1,1);
   if (prev->PTYPE == BIT64_S) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
   gtk_widget_show(button);
   raw->typeBIT64_S=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"Uint64");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,1,2,4,5);
+  gtk_grid_attach(GTK_GRID(grid),button,1,4,1,1);
   if (prev->PTYPE == BIT64_U) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
   gtk_widget_show(button);
   raw->typeBIT64_U=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"float");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,0,1,5,6);
+  gtk_grid_attach(GTK_GRID(grid),button,0,5,1,1);
   if (prev->PTYPE == FLT32) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
   gtk_widget_show(button);
   raw->typeFLT32=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"double");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,1,2,5,6);
+  gtk_grid_attach(GTK_GRID(grid),button,1,5,1,1);
   if (prev->PTYPE == FLT64) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
   gtk_widget_show(button);
   raw->typeFLT64=button;
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"RGB");
-  gtk_table_attach_defaults(GTK_TABLE(table),button,0,1,6,7);
+  gtk_grid_attach(GTK_GRID(grid),button,0,6,1,1);
   if (prev->PTYPE == COLRGB) {
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   }
@@ -566,11 +561,11 @@ void XMdcGetImageInfo(void)
   raw->typeCOLRGB=button;
 
 
-  separator = gtk_hseparator_new();
+  separator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
   gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
   gtk_widget_show (separator);
 
-  box2 = gtk_hbox_new(FALSE,0);
+  box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
   gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,2);
   gtk_widget_show(box2);
 
@@ -580,23 +575,23 @@ void XMdcGetImageInfo(void)
     button = gtk_button_new_with_label ("Next");
   }
   gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 2);
-  gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(gtk_widget_hide),
-                     GTK_OBJECT(window));
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(XMdcGetImageInfoCallbackApply), NULL);
-  gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(gtk_widget_destroy),
-                     GTK_OBJECT(window));
+  g_signal_connect_swapped(button, "clicked",
+                     G_CALLBACK(gtk_widget_hide),
+                     window);
+  g_signal_connect(button, "clicked",
+                     G_CALLBACK(XMdcGetImageInfoCallbackApply), NULL);
+  g_signal_connect_swapped(button, "clicked",
+                     G_CALLBACK(gtk_widget_destroy),
+                     window);
   gtk_widget_show(button);
 
   button = gtk_button_new_with_label("Cancel");
   gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 2);
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(XMdcGetImageInfoCallbackCancel), NULL);
-  gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(gtk_widget_destroy),
-                     GTK_OBJECT(window));
+  g_signal_connect(button, "clicked",
+                     G_CALLBACK(XMdcGetImageInfoCallbackCancel), NULL);
+  g_signal_connect_swapped(button, "clicked",
+                     G_CALLBACK(gtk_widget_destroy),
+                     window);
   gtk_widget_show(button);
 
   XMdcShowWidget(window);
@@ -634,7 +629,7 @@ void XMdcGetHeaderInfoCallbackApply(void)
   MdcDebugPrint("image  header offset = %u",input->gen_offset);
 
   /* image   header repeated */
-  if (GTK_TOGGLE_BUTTON(raw->IhdrRep)->active) {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->IhdrRep))) {
     input->REPEAT = MDC_YES; prev->HDRREP = MDC_YES;
     MdcDebugPrint("image  header repeated = yes");
   }else{
@@ -643,7 +638,7 @@ void XMdcGetHeaderInfoCallbackApply(void)
   }
 
   /* swap pixel bytes */
-  if (GTK_TOGGLE_BUTTON(raw->PixSwap)->active) {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->PixSwap))) {
     MDC_FILE_ENDIAN = !MDC_HOST_ENDIAN; prev->PSWAP = MDC_YES;
     MdcDebugPrint("swap pixels = yes");
   }else{
@@ -652,7 +647,7 @@ void XMdcGetHeaderInfoCallbackApply(void)
   }
 
   /* identical images */
-  if (GTK_TOGGLE_BUTTON(raw->ImgSame)->active) {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->ImgSame))) {
     input->DIFF = MDC_NO; prev->DIFF = MDC_NO;
     MdcDebugPrint("identical images = yes");
     raw->ImgCounter = my.fi->number;
@@ -673,26 +668,26 @@ void XMdcGetHeaderInfo(void)
   GtkWidget *box2;
   GtkWidget *box3;
   GtkWidget *frame;
-  GtkWidget *table;
+  GtkWidget *grid;
   GtkWidget *label;
   GtkWidget *button;
   GtkWidget *entry;
   GtkWidget *separator;
 
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  gtk_signal_connect(GTK_OBJECT(window),"destroy",
-                     GTK_SIGNAL_FUNC(XMdcWidgetCallbackDestroy),NULL);
+  g_signal_connect(window,"destroy",
+                     G_CALLBACK(XMdcWidgetCallbackDestroy),NULL);
   gtk_window_set_title(GTK_WINDOW(window),"Input Header Info");
   raw->HdrInfoWindow = window;
 
   gtk_container_set_border_width(GTK_CONTAINER(window), 0);
 
-  box1 = gtk_vbox_new(FALSE,0);
+  box1 = gtk_box_new(GTK_ORIENTATION_VERTICAL,0);
   gtk_container_add(GTK_CONTAINER(window),box1);
   gtk_container_set_border_width(GTK_CONTAINER(box1),0);
   gtk_widget_show(box1);
 
-  box2 = gtk_hbox_new(FALSE,5);
+  box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,5);
   gtk_container_add(GTK_CONTAINER(box1),box2);
   gtk_container_set_border_width(GTK_CONTAINER(box2),5);
   gtk_widget_show(box2);
@@ -701,51 +696,56 @@ void XMdcGetHeaderInfo(void)
   gtk_box_pack_start(GTK_BOX(box2),frame,TRUE,TRUE,5);
   gtk_widget_show(frame);
 
-  box3 = gtk_vbox_new(FALSE,5);
+  box3 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
   gtk_container_add(GTK_CONTAINER(frame),box3);
   gtk_container_set_border_width(GTK_CONTAINER(box3),5);
   gtk_widget_show(box3);
 
-  table = gtk_table_new(4,2,FALSE);
-  gtk_container_add(GTK_CONTAINER(box3),table);
-  gtk_widget_show(table);
+  grid = gtk_grid_new();
+  gtk_container_add(GTK_CONTAINER(box3),grid);
+  gtk_widget_show(grid);
 
   label = gtk_label_new("        Total number of images ");
   gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
   gtk_widget_set_name (label, "FixedLabel");
-  gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,0,1);
+  gtk_grid_attach(GTK_GRID(grid),label,0,0,1,1);
   gtk_widget_show(label);
-  entry = gtk_entry_new_with_max_length(10);
+
+  entry = gtk_entry_new();
+  gtk_entry_set_max_length(GTK_ENTRY(entry), 10);
   sprintf(xmdcstr,"%u",prev->NRIMGS);
   gtk_entry_set_text(GTK_ENTRY(entry),xmdcstr);
   gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-  gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,0,1);
+  gtk_grid_attach(GTK_GRID(grid),entry,1,0,1,1);
   gtk_widget_show(entry);
   raw->NrImages = entry;
 
   label = gtk_label_new(" General header offset (bytes) ");
   gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
   gtk_widget_set_name (label, "FixedLabel");
-  gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
+  gtk_grid_attach(GTK_GRID(grid),label,0,1,1,1);
   gtk_widget_show(label);
-  entry = gtk_entry_new_with_max_length(10);
+
+  entry = gtk_entry_new();
+  gtk_entry_set_max_length(GTK_ENTRY(entry), 10);
   sprintf(xmdcstr,"%u",prev->GENHDR);
   gtk_entry_set_text(GTK_ENTRY(entry),xmdcstr);
   gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-  gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,1,2);
+  gtk_grid_attach(GTK_GRID(grid),entry,1,1,1,1);
   gtk_widget_show(entry);
   raw->GenOffset = entry;
 
   label = gtk_label_new(" Image   header offset (bytes) ");
   gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
   gtk_widget_set_name (label, "FixedLabel");
-  gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,2,3);
+  gtk_grid_attach(GTK_GRID(grid),label,0,2,1,1);
   gtk_widget_show(label);
-  entry = gtk_entry_new_with_max_length(10);
+
+  entry = gtk_entry_new();
+  gtk_entry_set_max_length(GTK_ENTRY(entry), 10);
   sprintf(xmdcstr,"%u",prev->IMGHDR);
   gtk_entry_set_text(GTK_ENTRY(entry),xmdcstr);
-  gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-  gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,2,3);
+  gtk_grid_attach(GTK_GRID(grid),entry,1,2,1,1);
   gtk_widget_show(entry);
   raw->ImgOffset = entry;
 
@@ -753,7 +753,7 @@ void XMdcGetHeaderInfo(void)
   gtk_box_pack_start(GTK_BOX(box2),frame,TRUE,TRUE,5);
   gtk_widget_show(frame);
 
-  box3 = gtk_vbox_new(FALSE, 5);
+  box3 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
   gtk_container_add(GTK_CONTAINER(frame),box3);
   gtk_container_set_border_width(GTK_CONTAINER(box3),5);
   gtk_widget_show(box3);
@@ -779,28 +779,28 @@ void XMdcGetHeaderInfo(void)
   gtk_widget_show(button);
   raw->ImgSame = button;
 
-  separator = gtk_hseparator_new();
+  separator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
   gtk_box_pack_start(GTK_BOX(box1),separator,FALSE,FALSE,0);
   gtk_widget_show(separator);
 
-  box2 = gtk_hbox_new(FALSE,0);
+  box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
   gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,2);
   gtk_widget_show(box2);
 
   button = gtk_button_new_with_label("Continue");
   gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(XMdcGetHeaderInfoCallbackApply),NULL);
-  gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                    GTK_SIGNAL_FUNC(gtk_widget_hide),
-                    GTK_OBJECT(window));
+  g_signal_connect(button, "clicked",
+                     G_CALLBACK(XMdcGetHeaderInfoCallbackApply),NULL);
+  g_signal_connect_swapped(button, "clicked",
+                    G_CALLBACK(gtk_widget_hide),
+                    window);
   gtk_widget_show(button);
 
   button = gtk_button_new_with_label("Cancel");
   gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-  gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                    GTK_SIGNAL_FUNC(gtk_widget_destroy),
-                    GTK_OBJECT(window));
+  g_signal_connect_swapped(button, "clicked",
+                    G_CALLBACK(gtk_widget_destroy),
+                    window);
   gtk_widget_show(button);
 
   XMdcShowWidget(window);
