@@ -16,11 +16,11 @@
  *                XMdcViewerDisableAutoShrink()- Disable auto shrinking    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -81,9 +81,9 @@ int XMdcGetBoardDimensions(void)
 
      /* inside the screen boundaries ? */
      if ((trial_images_vertical   * mheight) >
-         (gdk_screen_height() - XMDC_FREE_BORDER)) FOUND = MDC_NO;
+         (my.screen_height - XMDC_FREE_BORDER)) FOUND = MDC_NO;
      if ((trial_images_horizontal * mwidth) >
-         (gdk_screen_width()  - XMDC_FREE_BORDER)) FOUND = MDC_NO;
+         (my.screen_width  - XMDC_FREE_BORDER)) FOUND = MDC_NO;
 
    }
 
@@ -103,9 +103,9 @@ int XMdcGetBoardDimensions(void)
 
           /* inside the screen boundaries ? */
           if ((trial_images_vertical   * mheight) >
-              (gdk_screen_height() - XMDC_FREE_BORDER)) FOUND = MDC_NO;
+              (my.screen_height - XMDC_FREE_BORDER)) FOUND = MDC_NO;
           if ((trial_images_horizontal * mwidth) >
-              (gdk_screen_width()  - XMDC_FREE_BORDER)) FOUND = MDC_NO;
+              (my.screen_width  - XMDC_FREE_BORDER)) FOUND = MDC_NO;
 
         }
 
@@ -128,9 +128,9 @@ int XMdcGetBoardDimensions(void)
 
      /* inside the screen boundaries ? */
      if ((trial_images_vertical   * mheight) >
-         (gdk_screen_height() - XMDC_FREE_BORDER)) FOUND = MDC_NO;
+         (my.screen_height - XMDC_FREE_BORDER)) FOUND = MDC_NO;
      if ((trial_images_horizontal * mwidth) >
-         (gdk_screen_width()  - XMDC_FREE_BORDER)) FOUND = MDC_NO;
+         (my.screen_width  - XMDC_FREE_BORDER)) FOUND = MDC_NO;
 
    }
 
@@ -160,9 +160,9 @@ int XMdcGetBoardDimensions(void)
    }
 
    /* final fallback based on screen dimensions */
-   arbitrary_row = (gdk_screen_height() - XMDC_FREE_BORDER)
+   arbitrary_row = (my.screen_height - XMDC_FREE_BORDER)
                     / XMdcScaleH(my.fi->mheight);
-   arbitrary_col = (gdk_screen_width()  - XMDC_FREE_BORDER)
+   arbitrary_col = (my.screen_width  - XMDC_FREE_BORDER)
                     / XMdcScaleW(my.fi->mwidth);
 
    if (arbitrary_row == 0 || arbitrary_col == 0) {
@@ -260,36 +260,17 @@ void XMdcHandleBoardDimensions(void)
     XMdcDisplayFatalErr(MDC_BAD_ALLOC,"Couldn't malloc Images array");
   }
 
-#ifdef MDC_USE_SIGNAL_BLOCKER
-  my.sblkr=(SignalBlocker *)malloc(sizeof(SignalBlocker)*my.images_per_page);
-  if (my.sblkr == NULL) {
-    MdcFree(my.im);
-    MdcFree(my.imagenumber);
-    MdcFree(my.realnumber);
-    MdcFree(my.pagenumber);
-    MdcFree(my.image);
-    MdcCleanUpFI(my.fi);
-    XMdcDisplayFatalErr(MDC_BAD_ALLOC,"Couldn't malloc SignalBlockers");
-  }
-#else
-  my.sblkr = NULL;
-#endif
-
   for (i = 0; i<my.images_per_page; i++) {
      my.im[i] = NULL;
      my.imagenumber[i]=i;
      my.realnumber[i]=0;
      my.image[i]=NULL;
-#ifdef MDC_USE_SIGNAL_BLOCKER
-     my.sblkr[i].id = 0;
-     my.sblkr[i].blocked = FALSE;
-#endif
   }
 
   for (i = 0; i<my.number_of_pages; i++) my.pagenumber[i] = i;
 
-  MdcDebugPrint("screen_width      = %d",gdk_screen_width());
-  MdcDebugPrint("screen_height     = %d",gdk_screen_height());
+  MdcDebugPrint("screen_width      = %d",my.screen_width);
+  MdcDebugPrint("screen_height     = %d",my.screen_height);
   MdcDebugPrint("mwidth            = %u",my.fi->mwidth);
   MdcDebugPrint("mheight           = %u",my.fi->mheight);
   MdcDebugPrint("resize            = %d",sResizeSelection.CurType);
@@ -321,12 +302,12 @@ void XMdcBuildViewerWindow(void)
 
   if (my.viewwindow == NULL) {
     my.viewwindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_policy(GTK_WINDOW(my.viewwindow),FALSE,FALSE,FALSE);
+    gtk_window_set_resizable(GTK_WINDOW(my.viewwindow), FALSE);
 
-    gtk_signal_connect(GTK_OBJECT(my.viewwindow), "delete-event",
-                       GTK_SIGNAL_FUNC(XMdcViewerHide), NULL);
-    gtk_signal_connect(GTK_OBJECT(my.viewwindow), "destroy",
-                       GTK_SIGNAL_FUNC(XMdcMedconQuit), NULL);
+    g_signal_connect(my.viewwindow, "delete-event",
+                       G_CALLBACK(XMdcViewerHide), NULL);
+    g_signal_connect(my.viewwindow, "destroy",
+                       G_CALLBACK(XMdcMedconQuit), NULL);
     gtk_container_set_border_width(GTK_CONTAINER (my.viewwindow), 0);
   }
 
@@ -334,30 +315,30 @@ void XMdcBuildViewerWindow(void)
 
   gtk_widget_realize(my.viewwindow);
 
-  box1 = gtk_vbox_new(FALSE, 0);
+  box1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add(GTK_CONTAINER (my.viewwindow), box1);
   gtk_widget_show(box1);
 
   my.viewbox = box1;
 
-  box2 = gtk_hbox_new(FALSE, 0);
+  box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start(GTK_BOX(box1),box2,FALSE,FALSE,0);
   gtk_widget_show(box2);
 
-  my.pagemenu = gtk_option_menu_new();
-  gtk_option_menu_set_menu(GTK_OPTION_MENU(my.pagemenu),XMdcPagesCreateMenu());
+  my.pagemenu = XMdcPagesCreateMenu();
+
   gtk_box_pack_start(GTK_BOX(box2),my.pagemenu,TRUE,TRUE,0);
   gtk_widget_show(my.pagemenu);
 
   button = gtk_button_new_with_label("Next");
-  gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
-                     GTK_SIGNAL_FUNC(XMdcPagesNext),NULL);
+  g_signal_connect(button, "button-release-event",
+                     G_CALLBACK(XMdcPagesCbNext),NULL);
   gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,0);
   gtk_widget_show(button);
 
   button = gtk_button_new_with_label("Prev");
-  gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
-                     GTK_SIGNAL_FUNC(XMdcPagesPrev),NULL);
+  g_signal_connect(button, "button-release-event",
+                     G_CALLBACK(XMdcPagesCbPrev),NULL);
   gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,0);
   gtk_widget_show(button);
 
@@ -368,20 +349,20 @@ void XMdcBuildViewerWindow(void)
   gtk_box_pack_start(GTK_BOX(box1),frame,TRUE,TRUE,0);
   gtk_widget_show(frame);
 
-  winbox = gtk_hbox_new(FALSE, 0);
+  winbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_container_add(GTK_CONTAINER(frame),winbox);
   gtk_widget_show(winbox);
 
-  my.imgsbox = gtk_hbox_new(TRUE,0);
+  my.imgsbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
   gtk_container_set_border_width(GTK_CONTAINER(my.imgsbox),0);
   gtk_box_pack_start(GTK_BOX(winbox),my.imgsbox,TRUE,TRUE,0);
   gtk_widget_show(my.imgsbox);
 
-  my.imgstable=gtk_table_new(my.images_vertical,my.images_horizontal,TRUE);
-  gtk_box_pack_start(GTK_BOX(my.imgsbox), my.imgstable, TRUE, TRUE, 0);
-  gtk_widget_show(my.imgstable);
+  my.imgsgrid=gtk_grid_new();
+  gtk_box_pack_start(GTK_BOX(my.imgsbox), my.imgsgrid, TRUE, TRUE, 0);
+  gtk_widget_show(my.imgsgrid);
 
-  separator = gtk_vseparator_new();
+  separator = gtk_separator_new(GTK_ORIENTATION_VERTICAL);
   gtk_box_pack_start(GTK_BOX(winbox), separator, FALSE, FALSE, 0);
   gtk_widget_show(separator);
 
@@ -392,17 +373,17 @@ void XMdcBuildViewerWindow(void)
   XMdcApplyMapPlace(XMDC_CMAP_PLACE);
 
   /* seperator */
-  separator = gtk_hseparator_new();
+  separator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
   gtk_box_pack_start(GTK_BOX(box1), separator, FALSE, TRUE, 0);
 
   /* layout for buttons */
 
-  vbox = gtk_vbox_new(FALSE, 2);
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
   gtk_container_set_border_width(GTK_CONTAINER(box2), 0);
   gtk_box_pack_start(GTK_BOX(box1), vbox, FALSE, TRUE, 0);
   gtk_widget_show(vbox);
 
-  box2 = gtk_hbox_new(FALSE, 2);
+  box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
   gtk_container_set_border_width(GTK_CONTAINER(box2), 0);
   gtk_box_pack_start(GTK_BOX(vbox), box2, FALSE, FALSE, 0);
   gtk_widget_show(box2);
@@ -412,14 +393,14 @@ void XMdcBuildViewerWindow(void)
   gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,0);
   gtk_widget_show(button);
 
-  entrybox = gtk_hbox_new(FALSE, 2);
+  entrybox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
   gtk_container_set_border_width(GTK_CONTAINER(box2), 0);
   gtk_box_pack_start(GTK_BOX(box2), entrybox, FALSE, FALSE, 0);
   gtk_widget_show(entrybox);
 
-  gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                            GTK_SIGNAL_FUNC(XMdcToggleVisibility),
-                            GTK_OBJECT(entrybox));
+  g_signal_connect_swapped(button, "clicked",
+                            G_CALLBACK(XMdcToggleVisibility),
+                            entrybox);
 
   label = gtk_label_new("Page: ");
   gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
@@ -432,24 +413,13 @@ void XMdcBuildViewerWindow(void)
 
   spinner = gtk_spin_button_new(adj, 0.0, 0);
   gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(spinner), TRUE);
-#ifdef GTKONE
-  gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spinner),
-                                  GTK_SHADOW_ETCHED_IN);
-#endif
   gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spinner), TRUE);
   gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON(spinner), TRUE);
 
   gtk_box_pack_start(GTK_BOX(entrybox),spinner,FALSE,FALSE,5);
 
-#ifdef GTKONE
-  gtk_signal_connect_after(GTK_OBJECT(spinner),"key_press_event",
-                     GTK_SIGNAL_FUNC(XMdcPagesGoTo),NULL);
-  gtk_signal_connect_after(GTK_OBJECT(spinner), "button_release_event",
-                           GTK_SIGNAL_FUNC(XMdcPagesGoTo),NULL);
-#else
-  gtk_signal_connect(GTK_OBJECT(spinner),"value_changed",
-                     GTK_SIGNAL_FUNC(XMdcPagesGoTo),NULL);
-#endif
+  g_signal_connect(spinner, "value_changed",
+                     G_CALLBACK(XMdcPagesCbGoTo),NULL);
   gtk_widget_show(spinner);
 
   label = gtk_label_new("Table: ");
@@ -463,46 +433,35 @@ void XMdcBuildViewerWindow(void)
 
   spinner = gtk_spin_button_new(adj, 0.0, 0);
   gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(spinner), TRUE);
-#ifdef GTKONE
-  gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spinner),
-                                  GTK_SHADOW_ETCHED_IN);
-#endif
   gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spinner), TRUE);
   gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON(spinner), TRUE);
 
   gtk_box_pack_start(GTK_BOX(entrybox),spinner,FALSE,FALSE,5);
 
-#ifdef GTKONE
-  gtk_signal_connect_after(GTK_OBJECT(spinner),"key_press_event",
-                     GTK_SIGNAL_FUNC(XMdcChangeLUT),NULL);
-  gtk_signal_connect_after(GTK_OBJECT(spinner), "button_release_event",
-                           GTK_SIGNAL_FUNC(XMdcChangeLUT),NULL);
-#else
-  gtk_signal_connect(GTK_OBJECT(spinner),"value_changed",
-                     GTK_SIGNAL_FUNC(XMdcChangeLUT),NULL);
-#endif
+  g_signal_connect(spinner, "value_changed",
+                     G_CALLBACK(XMdcChangeLUT),NULL);
   gtk_widget_show(spinner);
 
-  box2 = gtk_hbox_new(FALSE, 2);
+  box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
   gtk_container_set_border_width(GTK_CONTAINER(box2), 0);
   gtk_box_pack_start(GTK_BOX(vbox), box2, FALSE, TRUE, 0);
   gtk_widget_show(box2);
 
   button = gtk_button_new_with_label(" Hide ");
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(XMdcViewerHide), NULL);
+  g_signal_connect(button, "clicked",
+                     G_CALLBACK(XMdcViewerHide), NULL);
   gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
   button = gtk_button_new_with_label("Labels");
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(XMdcLabelSel), NULL);
+  g_signal_connect(button, "clicked",
+                     G_CALLBACK(XMdcLabelSel), NULL);
   gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
   button = gtk_button_new_with_label("Render");
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(XMdcRenderingSel), NULL);
+  g_signal_connect(button, "clicked",
+                     G_CALLBACK(XMdcRenderingSel), NULL);
   gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
@@ -528,16 +487,16 @@ void XMdcViewerShow(void)
 void XMdcViewerEnableAutoShrink(void)
 {
   if (my.viewwindow != NULL) {
-    MdcDebugPrint("enable auto shrink");
-    gtk_window_set_policy(GTK_WINDOW(my.viewwindow),TRUE,TRUE,TRUE);
+    MdcDebugPrint("Enable auto shrink viewer window");
+    gtk_window_set_resizable(GTK_WINDOW(my.viewwindow), TRUE);
   }
 }
 
 void XMdcViewerDisableAutoShrink(void)
 {
   if (my.viewwindow != NULL) {
-    MdcDebugPrint("disable auto shrink");
-    gtk_window_set_policy(GTK_WINDOW(my.viewwindow),FALSE,FALSE,FALSE);
+    MdcDebugPrint("Disable auto shrink viewer window");
+    gtk_window_set_resizable(GTK_WINDOW(my.viewwindow), FALSE);
   }
 }
 
