@@ -11,11 +11,11 @@
  *                XMdcEditFileInfo()            - Edit FILEINFO struct     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2020 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -75,7 +75,7 @@ void XMdcEditFileInfoCallbackApply(GtkWidget *widget, gpointer data)
 
   /* Orientation */
   for (i=0; i < MDC_MAX_ORIENT; i++) {
-     if (GTK_TOGGLE_BUTTON(sEditFI.PatSliceOrient[i])->active) {
+     if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sEditFI.PatSliceOrient[i]))) {
        my.fi->pat_slice_orient = (Int8)i; break;
      }
   }
@@ -133,30 +133,30 @@ void XMdcEditFileInfoCallbackApply(GtkWidget *widget, gpointer data)
 
 
   /* Study Parameters */
-  if (GTK_TOGGLE_BUTTON(sEditFI.Reconstructed)->active) {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sEditFI.Reconstructed))) {
     my.fi->reconstructed = MDC_YES;
   }else{
     my.fi->reconstructed = MDC_NO;
   }
 
-  if (GTK_TOGGLE_BUTTON(sEditFI.Planar)->active) {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sEditFI.Planar))) {
     my.fi->planar = MDC_YES;
   }else{
     my.fi->planar = MDC_NO;
   }
 
-  if (GTK_TOGGLE_BUTTON(sEditFI.ModalityNM)->active) {
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sEditFI.ModalityNM))) {
     sEditFI.CurModality = M_NM;
-  }else if (GTK_TOGGLE_BUTTON(sEditFI.ModalityPT)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sEditFI.ModalityPT))) {
     sEditFI.CurModality = M_PT;
-  }else if (GTK_TOGGLE_BUTTON(sEditFI.ModalityCT)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sEditFI.ModalityCT))) {
     sEditFI.CurModality = M_CT;
-  }else if (GTK_TOGGLE_BUTTON(sEditFI.ModalityMR)->active) {
+  }else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sEditFI.ModalityMR))) {
     sEditFI.CurModality = M_MR;
   }
 
   for (i=0; i < MDC_MAX_ACQUISITIONS; i++) {
-     if (GTK_TOGGLE_BUTTON(sEditFI.AcquisitionType[i])->active) {
+     if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sEditFI.AcquisitionType[i]))) {
        my.fi->acquisition_type = (Int16) i; break;
      }
   }
@@ -230,7 +230,7 @@ void XMdcEditFileInfo(void)
    GtkWidget *frame;
    GtkWidget *top, *left, *right;
    GtkWidget *label;
-   GtkWidget *table;
+   GtkWidget *grid;
    GtkWidget *tablabel;
    GtkWidget *entry;
    GtkWidget *button;
@@ -244,56 +244,57 @@ void XMdcEditFileInfo(void)
 
    window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-   gtk_signal_connect(GTK_OBJECT(window),"destroy",
-                      GTK_SIGNAL_FUNC(gtk_widget_destroy),NULL);
+   g_signal_connect(window, "destroy",
+                      G_CALLBACK(gtk_widget_destroy),NULL);
 
    gtk_window_set_title(GTK_WINDOW(window),"Edit FileInfo");
    gtk_container_set_border_width(GTK_CONTAINER(window),0);
 
-   box1 = gtk_vbox_new(FALSE,5);
+   box1 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
    gtk_container_add(GTK_CONTAINER(window),box1);
    gtk_container_set_border_width(GTK_CONTAINER(box1),5);
    gtk_widget_show(box1);
 
-   label=gtk_label_new("* any changes can seriously damage study integrity *");
-   gtk_misc_set_alignment(GTK_MISC(label),0.5,0.5);
+   label = gtk_label_new(
+         " \n** any change can seriously damage study integrity **\n ");
+   gtk_widget_set_name(label, "WarningLabel");
+   gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+   gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
    gtk_box_pack_start(GTK_BOX(box1),label,TRUE,TRUE,0);
    gtk_widget_show(label);
 
    notebook = gtk_notebook_new();
    gtk_container_add(GTK_CONTAINER(box1),notebook);
    gtk_container_set_border_width(GTK_CONTAINER(notebook), 10);
-   gtk_notebook_set_tab_border(GTK_NOTEBOOK(notebook), 5);
-   gtk_notebook_set_homogeneous_tabs(GTK_NOTEBOOK(notebook), TRUE);
    gtk_widget_show(notebook);
 
    /* tab page Patient Slice Orientation */
-   box2 = gtk_hbox_new(FALSE, 10);
+   box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
    gtk_widget_show(box2);
 
    tablabel = gtk_label_new("Orientation");
    gtk_widget_show(tablabel);
    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), box2, tablabel);
 
-   box3 = gtk_vbox_new(FALSE,5);
+   box3 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
    gtk_container_add(GTK_CONTAINER(box2),box3);
    gtk_container_set_border_width(GTK_CONTAINER(box3),5);
    gtk_widget_show(box3);
 
-   table = gtk_table_new(2,2,FALSE);
-   gtk_container_add(GTK_CONTAINER(box3),table);
-   gtk_widget_show(table);
+   grid = gtk_grid_new();
+   gtk_container_add(GTK_CONTAINER(box3),grid);
+   gtk_widget_show(grid);
 
-   top = gtk_vbox_new(FALSE,5);
-   gtk_table_attach_defaults(GTK_TABLE(table),top,0,1,0,1);
+   top = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
+   gtk_grid_attach(GTK_GRID(grid),top,0,0,1,1);
    gtk_widget_show(top);
 
-   left = gtk_vbox_new(FALSE,5);
-   gtk_table_attach_defaults(GTK_TABLE(table),left,0,1,1,2);
+   left = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
+   gtk_grid_attach(GTK_GRID(grid),left,0,1,1,1);
    gtk_widget_show(left);
 
-   right = gtk_vbox_new(FALSE,5);
-   gtk_table_attach_defaults(GTK_TABLE(table),right,1,2,1,2);
+   right = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
+   gtk_grid_attach(GTK_GRID(grid),right,1,1,1,1);
    gtk_widget_show(right);
 
 
@@ -303,7 +304,7 @@ void XMdcEditFileInfo(void)
       if (i == 0) {
         button = gtk_radio_button_new_with_label(NULL,MdcGetStrPatSlOrient(i));
       }else{
-        group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+        group  = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
         button = gtk_radio_button_new_with_label(group,MdcGetStrPatSlOrient(i));
       }
 
@@ -329,7 +330,7 @@ void XMdcEditFileInfo(void)
    }
 
    /* tab page Sizes */
-   box2 = gtk_vbox_new(FALSE, 10);
+   box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 10);
    gtk_widget_show(box2);
 
    tablabel = gtk_label_new("Sizes / Time");
@@ -344,91 +345,91 @@ void XMdcEditFileInfo(void)
    gtk_box_pack_start(GTK_BOX(box2),label,TRUE,TRUE,5);
    gtk_widget_show(label);
 
-   box3 = gtk_vbox_new(FALSE,5);
+   box3 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
    gtk_container_add(GTK_CONTAINER(box2),box3);
    gtk_container_set_border_width(GTK_CONTAINER(box3),5);
    gtk_widget_show(box3);
 
-   table = gtk_table_new(4,3, FALSE);
-   gtk_container_add(GTK_CONTAINER(box3),table);
-   gtk_widget_show(table);
+   grid = gtk_grid_new();
+   gtk_container_add(GTK_CONTAINER(box3),grid);
+   gtk_grid_set_row_spacing(GTK_GRID(grid), 2);
+   gtk_grid_set_column_spacing(GTK_GRID(grid), 2);
+   gtk_grid_set_row_homogeneous(GTK_GRID(grid), TRUE);
+   gtk_grid_set_column_homogeneous(GTK_GRID(grid), TRUE);
+   gtk_widget_set_vexpand(grid, TRUE);
+   gtk_widget_show(grid);
 
    label = gtk_label_new("Pixel Size");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,0,1);
+   gtk_grid_attach(GTK_GRID(grid),label,0,0,1,1);
    gtk_widget_show(label);
 
-   entry = gtk_entry_new_with_max_length(15);
+   entry = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(entry), 15);
    sprintf(mdcbufr,"%e",my.fi->image[0].pixel_xsize);
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-   gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,0,1);
-#ifdef GTKONE
-   gtk_widget_draw_default(entry);
-#endif
+   gtk_grid_attach(GTK_GRID(grid),entry,1,0,1,1);
    gtk_widget_show(entry);
    vifi->PixelSize = entry;
 
    label = gtk_label_new("[mm]");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,2,3,0,1);
+   gtk_grid_attach(GTK_GRID(grid),label,2,0,1,1);
    gtk_widget_show(label);
 
    label = gtk_label_new("Slice Width");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
+   gtk_grid_attach(GTK_GRID(grid),label,0,1,1,1);
    gtk_widget_show(label);
 
-   entry = gtk_entry_new_with_max_length(15);
+   entry = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(entry), 15);
    sprintf(mdcbufr,"%e",my.fi->image[0].slice_width);
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-   gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,1,2);
-#ifdef GTKONE
-   gtk_widget_draw_default(entry);
-#endif
+   gtk_grid_attach(GTK_GRID(grid),entry,1,1,1,1);
    gtk_widget_show(entry);
    vifi->SliceWidth = entry;
 
    label = gtk_label_new("[mm]");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,2,3,1,2);
+   gtk_grid_attach(GTK_GRID(grid),label,2,1,1,1);
    gtk_widget_show(label);
 
    label = gtk_label_new("Slice Separation");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,2,3);
+   gtk_grid_attach(GTK_GRID(grid),label,0,2,1,1);
    gtk_widget_show(label);
 
-   entry = gtk_entry_new_with_max_length(15);
+   entry = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(entry), 15);
    sprintf(mdcbufr,"%e",my.fi->image[0].slice_spacing);
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-   gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,2,3);
-#ifdef GTKONE
-   gtk_widget_draw_default(entry);
-#endif
+   gtk_grid_attach(GTK_GRID(grid),entry,1,2,1,1);
    gtk_widget_show(entry);
    vifi->SliceSpacing = entry;
 
    label = gtk_label_new("[mm]");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,2,3,2,3);
+   gtk_grid_attach(GTK_GRID(grid),label,2,2,1,1);
    gtk_widget_show(label);
 
    label = gtk_label_new("Frame Duration");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,3,4);
+   gtk_grid_attach(GTK_GRID(grid),label,0,3,1,1);
    gtk_widget_show(label);
 
-   entry = gtk_entry_new_with_max_length(15);
+   entry = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(entry), 15);
    if ((my.fi->dynnr > 0) && (my.fi->dyndata != NULL)) {
      sprintf(mdcbufr,"%e",my.fi->dyndata[0].time_frame_duration);
    }else{
@@ -437,21 +438,18 @@ void XMdcEditFileInfo(void)
 
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-   gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,3,4);
-#ifdef GTKONE
-   gtk_widget_draw_default(entry);
-#endif
+   gtk_grid_attach(GTK_GRID(grid),entry,1,3,1,1);
    gtk_widget_show(entry);
    vifi->FrameDuration = entry;
 
    label = gtk_label_new("[ms]");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,2,3,3,4);
+   gtk_grid_attach(GTK_GRID(grid),label,2,3,1,1);
    gtk_widget_show(label);
 
    /* tab page Dimensions */
-   box2 = gtk_vbox_new(FALSE, 10);
+   box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 10);
    gtk_widget_show(box2);
 
    tablabel = gtk_label_new("Dimensions");
@@ -466,141 +464,137 @@ void XMdcEditFileInfo(void)
    gtk_box_pack_start(GTK_BOX(box2),label,TRUE,TRUE,5);
    gtk_widget_show(label);
 
-   box3 = gtk_vbox_new(FALSE,5);
+   box3 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
    gtk_container_add(GTK_CONTAINER(box2),box3);
    gtk_container_set_border_width(GTK_CONTAINER(box3),5);
    gtk_widget_show(box3);
 
-   table = gtk_table_new(5,3, FALSE);
-   gtk_container_add(GTK_CONTAINER(box3),table);
-   gtk_widget_show(table);
+   grid = gtk_grid_new();
+   gtk_container_add(GTK_CONTAINER(box3),grid);
+   gtk_grid_set_row_spacing(GTK_GRID(grid), 2);
+   gtk_grid_set_column_spacing(GTK_GRID(grid), 2);
+   gtk_grid_set_row_homogeneous(GTK_GRID(grid), TRUE);
+   gtk_grid_set_column_homogeneous(GTK_GRID(grid), TRUE);
+   gtk_widget_set_vexpand(grid, TRUE);
+   gtk_widget_show(grid);
 
    label = gtk_label_new("dim[3] = ");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,0,1);
+   gtk_grid_attach(GTK_GRID(grid),label,0,0,1,1);
    gtk_widget_show(label);
 
-   entry = gtk_entry_new_with_max_length(15);
+   entry = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(entry), 15);
    sprintf(mdcbufr,"%u",my.fi->dim[3]);
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-   gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,0,1);
-#ifdef GTKONE
-   gtk_widget_draw_default(entry);
-#endif
+   gtk_grid_attach(GTK_GRID(grid),entry,1,0,1,1);
    gtk_widget_show(entry);
    vifi->NrDimPlanes = entry;
 
    label = gtk_label_new("(planes | (time) slices)");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,2,3,0,1);
+   gtk_grid_attach(GTK_GRID(grid),label,2,0,1,1);
    gtk_widget_show(label);
 
    label = gtk_label_new("dim[4] = ");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
+   gtk_grid_attach(GTK_GRID(grid),label,0,1,1,1);
    gtk_widget_show(label);
 
-   entry = gtk_entry_new_with_max_length(15);
+   entry = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(entry), 15);
    sprintf(mdcbufr,"%u",my.fi->dim[4]);
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-   gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,1,2);
-#ifdef GTKONE
-   gtk_widget_draw_default(entry);
-#endif
+   gtk_grid_attach(GTK_GRID(grid),entry,1,1,1,1);
    gtk_widget_show(entry);
    vifi->NrDimFrames = entry;
 
    label = gtk_label_new(" (frames | time slots | phases)");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,2,3,1,2);
+   gtk_grid_attach(GTK_GRID(grid),label,2,1,1,1);
    gtk_widget_show(label);
 
    label = gtk_label_new("dim[5] = ");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,2,3);
+   gtk_grid_attach(GTK_GRID(grid),label,0,2,1,1);
    gtk_widget_show(label);
 
-   entry = gtk_entry_new_with_max_length(15);
+   entry = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(entry), 15);
    sprintf(mdcbufr,"%u",my.fi->dim[5]);
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-   gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,2,3);
-#ifdef GTKONE
-   gtk_widget_draw_default(entry);
-#endif
+   gtk_grid_attach(GTK_GRID(grid),entry,1,2,1,1);
    gtk_widget_show(entry);
    vifi->NrDimGates = entry;
 
    label = gtk_label_new("(gates | R-R intervals)");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,2,3,2,3);
+   gtk_grid_attach(GTK_GRID(grid),label,2,2,1,1);
    gtk_widget_show(label);
 
    label = gtk_label_new("dim[6] = ");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,3,4);
+   gtk_grid_attach(GTK_GRID(grid),label,0,3,1,1);
    gtk_widget_show(label);
 
-   entry = gtk_entry_new_with_max_length(15);
+   entry = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(entry), 15);
    sprintf(mdcbufr,"%u",my.fi->dim[6]);
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-   gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,3,4);
-#ifdef GTKONE
-   gtk_widget_draw_default(entry);
-#endif
+   gtk_grid_attach(GTK_GRID(grid),entry,1,3,1,1);
    gtk_widget_show(entry);
    vifi->NrDimBeds = entry;
 
    label = gtk_label_new("(beds | detector heads)");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,2,3,3,4);
+   gtk_grid_attach(GTK_GRID(grid),label,2,3,1,1);
    gtk_widget_show(label);
 
    label = gtk_label_new("dim[7] = ");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,4,5);
+   gtk_grid_attach(GTK_GRID(grid),label,0,4,1,1);
    gtk_widget_show(label);
 
-   entry = gtk_entry_new_with_max_length(15);
+   entry = gtk_entry_new();
+   gtk_entry_set_max_length(GTK_ENTRY(entry), 15);
    sprintf(mdcbufr,"%u",my.fi->dim[7]);
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
-   gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,4,5);
-#ifdef GTKONE
-   gtk_widget_draw_default(entry);
-#endif
+   gtk_grid_attach(GTK_GRID(grid),entry,1,4,1,1);
    gtk_widget_show(entry);
    vifi->NrDimWindows = entry;
 
    label = gtk_label_new("(energy windows)");
    gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
    gtk_widget_set_name(label, "FixedLabel");
-   gtk_table_attach_defaults(GTK_TABLE(table),label,2,3,4,5);
+   gtk_grid_attach(GTK_GRID(grid),label,2,4,1,1);
    gtk_widget_show(label);
 
    /* tab page Study Parameters */
-   box2 = gtk_vbox_new(FALSE, 10);
+   box2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 10);
    gtk_widget_show(box2);
 
    tablabel = gtk_label_new("Study Parameters");
    gtk_widget_show(tablabel);
    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), box2, tablabel);
 
-   box3 = gtk_hbox_new(FALSE,5);
+   box3 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,5);
    gtk_container_add(GTK_CONTAINER(box2),box3);
    gtk_container_set_border_width(GTK_CONTAINER(box3),5);
+   gtk_box_set_homogeneous(GTK_BOX(box3), TRUE);
    gtk_widget_show(box3);
 
    frame = gtk_frame_new("Reconstructed");
@@ -608,7 +602,7 @@ void XMdcEditFileInfo(void)
    gtk_container_set_border_width(GTK_CONTAINER(frame),5);
    gtk_widget_show(frame);
 
-   box4 = gtk_hbox_new(FALSE,5);
+   box4 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,5);
    gtk_container_add(GTK_CONTAINER(frame),box4);
    gtk_container_set_border_width(GTK_CONTAINER(box4),0);
    gtk_widget_show(box4);
@@ -621,7 +615,7 @@ void XMdcEditFileInfo(void)
    gtk_widget_show(button);
    vifi->Reconstructed = button;
 
-   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+   group  = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
    button = gtk_radio_button_new_with_label(group,"No");
    gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
    if (my.fi->reconstructed == MDC_NO)
@@ -633,7 +627,7 @@ void XMdcEditFileInfo(void)
    gtk_container_set_border_width(GTK_CONTAINER(frame),5);
    gtk_widget_show(frame);
 
-   box4 = gtk_hbox_new(FALSE,5);
+   box4 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,5);
    gtk_container_add(GTK_CONTAINER(frame),box4);
    gtk_container_set_border_width(GTK_CONTAINER(box4),0);
    gtk_widget_show(box4);
@@ -646,16 +640,18 @@ void XMdcEditFileInfo(void)
    gtk_widget_show(button);
    vifi->Planar = button;
 
-   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+   group  = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
    button = gtk_radio_button_new_with_label(group,"No");
    gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
    if (my.fi->planar == MDC_NO)
      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
    gtk_widget_show(button); /* MARK: no need to preserve, only two supported */
 
-   box3 = gtk_hbox_new(FALSE,5);
+   box3 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,5);
    gtk_container_add(GTK_CONTAINER(box2),box3);
    gtk_container_set_border_width(GTK_CONTAINER(box3),5);
+   gtk_box_set_homogeneous(GTK_BOX(box3), TRUE);
+   gtk_widget_set_vexpand(box3, TRUE); /* MARK */
    gtk_widget_show(box3);
 
    frame = gtk_frame_new("Acquisition Type");
@@ -663,7 +659,7 @@ void XMdcEditFileInfo(void)
    gtk_container_set_border_width(GTK_CONTAINER(frame),5);
    gtk_widget_show(frame);
 
-   box4 = gtk_vbox_new(FALSE,5);
+   box4 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
    gtk_container_add(GTK_CONTAINER(frame),box4);
    gtk_container_set_border_width(GTK_CONTAINER(box4),0);
    gtk_widget_show(box4);
@@ -672,7 +668,7 @@ void XMdcEditFileInfo(void)
       if (i == 0) {
         button = gtk_radio_button_new_with_label(NULL,MdcGetStrAcquisition(i));
       }else{
-        group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+        group  = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
         button = gtk_radio_button_new_with_label(group,MdcGetStrAcquisition(i));      }
 
       gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
@@ -691,7 +687,7 @@ void XMdcEditFileInfo(void)
    gtk_container_set_border_width(GTK_CONTAINER(frame),5);
    gtk_widget_show(frame);
 
-   box4 = gtk_vbox_new(FALSE,5);
+   box4 = gtk_box_new(GTK_ORIENTATION_VERTICAL,5);
    gtk_container_add(GTK_CONTAINER(frame),box4);
    gtk_container_set_border_width(GTK_CONTAINER(box4),0);
    gtk_widget_show(box4);
@@ -706,7 +702,7 @@ void XMdcEditFileInfo(void)
    gtk_widget_show(button);
    vifi->ModalityNM = button;
 
-   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+   group  = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
    button = gtk_radio_button_new_with_label(group,"PT");
    gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
    /*if (vifi->CurModality == M_PT) {
@@ -715,7 +711,7 @@ void XMdcEditFileInfo(void)
    gtk_widget_show(button);
    vifi->ModalityPT = button;
 
-   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+   group  = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
    button = gtk_radio_button_new_with_label(group,"CT");
    gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
    /*if (vifi->CurModality == M_CT) {
@@ -724,7 +720,7 @@ void XMdcEditFileInfo(void)
    gtk_widget_show(button);
    vifi->ModalityCT = button;
 
-   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+   group  = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
    button = gtk_radio_button_new_with_label(group,"MR");
    gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
    /*if (vifi->CurModality == M_MR) {
@@ -733,7 +729,7 @@ void XMdcEditFileInfo(void)
    gtk_widget_show(button);
    vifi->ModalityMR = button;
 
-   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+   group  = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
    button = gtk_radio_button_new_with_label(group,"keep current");
    gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
@@ -741,29 +737,29 @@ void XMdcEditFileInfo(void)
    vifi->ModalityCurrent = button;
 
    /* create horizontal separator */
-   separator = gtk_hseparator_new();
+   separator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start(GTK_BOX(box1),separator,FALSE,FALSE,0);
    gtk_widget_show(separator);
 
    /* create bottom buttons */
-   box2 = gtk_hbox_new(FALSE,0);
+   box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
    gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,2);
    gtk_widget_show(box2);
 
    button = gtk_button_new_with_label("Apply");
    gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-   gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                      GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(window));
-   gtk_signal_connect(GTK_OBJECT(button),"clicked",
-                      GTK_SIGNAL_FUNC(XMdcEditFileInfoCallbackApply), NULL);
-   gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
-                      GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(window));
+   g_signal_connect_swapped(button, "clicked",
+                      G_CALLBACK(gtk_widget_hide), window);
+   g_signal_connect(button, "clicked",
+                      G_CALLBACK(XMdcEditFileInfoCallbackApply), NULL);
+   g_signal_connect_swapped(button, "clicked",
+                      G_CALLBACK(gtk_widget_destroy), window);
    gtk_widget_show(button);
 
    button = gtk_button_new_with_label("Cancel");
    gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 2);
-   gtk_signal_connect_object(GTK_OBJECT (button), "clicked",
-                      GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(window));
+   g_signal_connect_swapped(button, "clicked",
+                      G_CALLBACK(gtk_widget_destroy), window);
    gtk_widget_show(button);
 
    XMdcShowWidget(window);
